"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs = __importStar(require("fs"));
var path = __importStar(require("path"));
var chalk_1 = __importDefault(require("chalk"));
var commander_1 = __importDefault(require("commander"));
var update_notifier_1 = __importDefault(require("update-notifier"));
var lib_1 = require("./lib");
// eslint-disable-next-line @typescript-eslint/no-var-requires
var pkg = require('../package.json');
// Notify for updates
if (pkg.version) {
    update_notifier_1.default({ pkg: pkg }).notify();
}
// base
commander_1.default
    .version(pkg.version || 'dev')
    .option('-m, --make-dir', 'Creates the output directory if it doesn\'t exist yet')
    .option('-t, --token <token>', 'Github token to be used (default: GH_TOKEN|GITHUB_TOKEN)', process.env.GH_TOKEN || process.env.GITHUB_TOKEN)
    .option('-v, --tag <tag>', 'Github release tag (default: GH_TAG|GITHUB_TAG)', process.env.GH_TAG || process.env.GITHUB_TAG)
    .option('-r, --repo <github repo slug>', 'Target github repository slug (default: GH_REPO|GITHUB_REPOSITORY)', process.env.GH_REPO || process.env.GITHUB_REPOSITORY)
    .option('-a, --asset <file name>', 'asset name (repeatable, default: GH_ASSET_NAME|GITHUB_ASSET_NAME)', function (value, prev) { return prev.includes(value)
    ? prev
    : prev.concat([value]); }, [process.env.GH_ASSET_NAME, process.env.GITHUB_ASSET_NAME]
    .filter(function (x) { return x; }))
    .option('-u, --unzip', 'Unpack .zip files automatically into a same-named folder')
    .option('-o, --output <path>', 'Output path for downloaded assets (default: CWD)', function (p) { return /^(\/|[A-Z]:\\).+/.test(p)
    ? p
    : path.resolve(process.cwd(), p); }, process.cwd());
// run
var cliName = 'screencloud/fetch-github-release cli';
console.log(chalk_1.default.white.underline.bold(cliName) + " " + chalk_1.default.gray("(" + (pkg.version || 'dev') + ")"));
var _a = commander_1.default.parse(process.argv), repo = _a.repo, output = _a.output, assets = _a.asset, token = _a.token, tag = _a.tag, _b = _a.makeDir, makeDir = _b === void 0 ? false : _b, _c = _a.unzip, unzip = _c === void 0 ? false : _c;
// console.log({assets, repo, output, makeDir, tag});
// no repo provided
if (!repo) {
    lib_1.die('github repo slug is not defined, use --repo <repo> or set REPO_SLUG beforehand');
}
else if (!/^[^\/]+\/[^\/]+$/.test(repo)) {
    lib_1.die("github repo slug is invalid: " + repo);
}
// no token provided
if (!token) {
    lib_1.die('github authentication token is not defined, use --token <token> or set GH_TOKEN beforehand');
}
// no tag provided
if (!tag) {
    lib_1.die('github release tag not defined, use --tag <tag> or set GH_TAG beforehand');
}
// output path doesn't exist
if (!fs.existsSync(output)) {
    if (!makeDir) {
        lib_1.die([
            "output path does not exist: " + output,
            "use --make-dir to automatically create the path or create it beforehand",
        ]);
    }
    else {
        // console.log(`creating output path: ${output}`);
        lib_1.ensureDirSync(output);
    }
}
else {
    // console.log(`output path already exists: ${output}`);
}
// asset list is empty
if (!assets.length) {
    lib_1.die("no assets provided for download. Use --asset or set GH_ASSET_NAME beforehand");
}
// Announce
console.log('\nConfiguration');
console.log('  github repository: ', repo);
console.log('  release tag:       ', tag);
console.log('  output folder:     ', output);
console.log('  unzip archives:    ', unzip ? chalk_1.default.green('yes') : chalk_1.default.gray('no'));
console.log('  target assets:     ', assets.join('\n                      '));
// load asset list
console.log('\nGetting list of available assets...');
var assetList = lib_1.curlAssetList({ tag: tag, repo: repo, token: token });
if (!assetList) {
    lib_1.die("Couldn't retrieve asset list, check your configuration and token permissions");
}
assetList.forEach(function (x) {
    console.log("  \u2192 " + x.name);
});
// filter assets to download
var targetAssets = assetList
    .filter(function (x) { return assets.includes(x.name); });
var missingAssets = assets
    .filter(function (a) { return !targetAssets.find(function (ta) { return ta.name === a; }); });
if (missingAssets.length) {
    lib_1.die(__spreadArrays(["Couldn't retrieve asset urls"], missingAssets.map(function (ma) { return "  \u2192 " + ma; })));
}
console.log("\nDownloading assets...");
targetAssets.forEach(function (_a) {
    var url = _a.url, name = _a.name;
    var start = Date.now();
    var outputFile = path.join(output, name);
    console.log("  \u2192 " + name);
    var size = lib_1.curlAsset({ token: token, url: url, outputFile: outputFile }).size;
    console.log("    File created: " + outputFile + " (" + size + " bytes, " + lib_1.stringifyInterval(Date.now() - start) + ")");
});
if (unzip) {
    console.log("\nUnzipping assets...");
    targetAssets
        .filter(function (x) { return x.name.endsWith('.zip'); })
        .forEach(function (_a) {
        var name = _a.name;
        var start = Date.now();
        console.log("  \u2192 " + name);
        var outputFolder = lib_1.unzipAsset({ name: name, output: output }).outputFolder;
        console.log("    Unzipped into: " + outputFolder + " (" + lib_1.stringifyInterval(Date.now() - start) + ")");
    });
}
console.log(chalk_1.default.green.bold("\nAll done!"));
