"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var child_process_1 = require("child_process");
var fs = __importStar(require("fs"));
var path = __importStar(require("path"));
var chalk_1 = __importDefault(require("chalk"));
function makePrefix(_a) {
    var token = _a.token, repo = _a.repo;
    return "https://" + token + "@api.github.com/repos/" + repo + "/releases";
}
exports.makePrefix = makePrefix;
function curlAssetList(_a) {
    var tag = _a.tag, token = _a.token, repo = _a.repo;
    var prefix = makePrefix({ token: token, repo: repo });
    var result = child_process_1.execSync("curl -s " + prefix + "/tags/" + tag).toString();
    // console.log(result);
    var assets = JSON.parse(result).assets;
    return assets;
}
exports.curlAssetList = curlAssetList;
function curlAsset(_a) {
    var token = _a.token, url = _a.url, outputFile = _a.outputFile;
    // use url prefixed authentication, this is removed on redirects.
    // (the -L in older versions of curl will pass on all headers including auth, which will fail on S3 asset downloads)
    //   302 with a location-header, which we have to follow
    //   200 with content being streamed in the body
    var tokenizedUrl = "https://" + token + "@" + url.substr(8);
    child_process_1.execSync("curl -sL -H \"Accept:application/octet-stream\" -o \"" + outputFile + "\" \"" + tokenizedUrl + "\"").toString();
    return {
        outputFile: outputFile,
        size: fs.statSync(outputFile).size,
    };
}
exports.curlAsset = curlAsset;
function ensureDirSync(dir) {
    fs.mkdirSync(dir, { recursive: true });
}
exports.ensureDirSync = ensureDirSync;
function unzipAsset(_a) {
    var name = _a.name, output = _a.output;
    var outputFile = path.join(output, name);
    var outputFolder = path.join(output, path.basename(name, path.extname(name)));
    ensureDirSync(outputFolder);
    // unzip on linux/windows
    child_process_1.execSync(process.platform === 'win32'
        ? "tar -kxf \"" + outputFile + "\" -C \"" + outputFolder + "\""
        : "unzip -o -d \"" + outputFolder + "\" \"" + outputFile + "\"").toString();
    return { outputFolder: outputFolder };
}
exports.unzipAsset = unzipAsset;
function stringifyInterval(i) {
    if (i < 1000) {
        return i + "ms";
    }
    else {
        return Math.round(i / 1000) + "s";
    }
}
exports.stringifyInterval = stringifyInterval;
function die(messageOrMessages) {
    var messages = Array.isArray(messageOrMessages)
        ? messageOrMessages
        : [messageOrMessages];
    console.error(chalk_1.default.red("\nFatal error"));
    messages.forEach(function (m) {
        console.error(m);
    });
    console.error('');
    process.exit(1);
}
exports.die = die;
