(function() {
	// NOTE: Should match syntheticDefaultExportPolyfill in LoaderAPI.ts
	function syntheticDefaultExportPolyfill(input) {
		if (
			input === null ||
			["function", "object", "array"].indexOf(typeof input) === -1 ||
			input.hasOwnProperty("default") // use hasOwnProperty to avoid triggering usage warnings from libraries like mobx
		) {
			return;
		}
		// to get around frozen input
		if (Object.isFrozen(input)) {
			input.default = input;
			return;
		}
		// free to define properties
		Object.defineProperty(input, "default", {
			value: input,
			writable: true,
			enumerable: false
		});
	}
	if (typeof global === "object") {
		global.require = require;
	}
	var $fsx = (global.$fsx = {});
	if ($fsx.r) {
		return;
	}
	$fsx.f = {};
	// cached modules
	$fsx.m = {};
	$fsx.s = function(id) {
		var result = $fsx.r(id);
		if (result === undefined) {
			var result = require(id);
			syntheticDefaultExportPolyfill(result);
			return result;
		}
	};
	$fsx.r = function(id) {
		var cached = $fsx.m[id];
		// resolve if in cache
		if (cached) {
			return cached.m.exports;
		}
		var file = $fsx.f[id];
		if (!file) return;
		cached = $fsx.m[id] = {};
		cached.exports = {};
		cached.m = { exports: cached.exports };
		file.call(cached.exports, cached.m, cached.exports);
		syntheticDefaultExportPolyfill(cached.m.exports);
		return cached.m.exports;
	};
})();
// default/cli.js
$fsx.f[0] =
function(module,exports){
var __importStar = this && this.__importStar || function (mod) {
    if (mod && mod.__esModule)
        return mod;
    var result = {};
    if (mod != null)
        for (var k in mod)
            if (Object.hasOwnProperty.call(mod, k))
                result[k] = mod[k];
    result['default'] = mod;
    return result;
};
var __importDefault = this && this.__importDefault || function (mod) {
    return mod && mod.__esModule ? mod : { 'default': mod };
};
Object.defineProperty(exports, '__esModule', { value: true });
const fs = __importStar($fsx.s('fs'));
const path = __importStar($fsx.s('path'));
const chalk_1 = __importDefault($fsx.r(4));
const commander_1 = __importDefault($fsx.r(11));
const update_notifier_1 = __importDefault($fsx.r(15));
const lib_1 = $fsx.r(1);
const pkg = $fsx.s('../package.json');
if (pkg.version) {
    update_notifier_1.default({ pkg }).notify();
}
commander_1.default.version(pkg.version || 'dev').option('-m, --make-dir', 'Creates the output directory if it doesn\'t exist yet').option('-t, --token <token>', 'Github token to be used (default: GH_TOKEN|GITHUB_TOKEN)', process.env.GH_TOKEN || process.env.GITHUB_TOKEN).option('-v, --tag <tag>', 'Github release tag (default: GH_TAG|GITHUB_TAG)', process.env.GH_TAG || process.env.GITHUB_TAG).option('-r, --repo <github repo slug>', 'Target github repository slug (default: GH_REPO|GITHUB_REPOSITORY)', process.env.GH_REPO || process.env.GITHUB_REPOSITORY).option('-a, --asset <file name>', 'asset name (repeatable, default: GH_ASSET_NAME|GITHUB_ASSET_NAME)', (value, prev) => prev.includes(value) ? prev : prev.concat([value]), [
    process.env.GH_ASSET_NAME,
    process.env.GITHUB_ASSET_NAME
].filter(x => x)).option('-u, --unzip', 'Unpack .zip files automatically into a same-named folder').option('-o, --output <path>', 'Output path for downloaded assets (default: CWD)', p => /^(\/|[A-Z]:\\).+/.test(p) ? p : path.resolve(process.cwd(), p), process.cwd());
const cliName = 'screencloud/fetch-github-release cli';
console.log(`${ chalk_1.default.white.underline.bold(cliName) } ${ chalk_1.default.gray(`(${ pkg.version || 'dev' })`) }`);
const {
    repo,
    output,
    asset: assets,
    token,
    tag,
    makeDir = false,
    unzip = false
} = commander_1.default.parse(process.argv);
if (!repo) {
    lib_1.die('github repo slug is not defined, use --repo <repo> or set REPO_SLUG beforehand');
} else if (!/^[^\/]+\/[^\/]+$/.test(repo)) {
    lib_1.die(`github repo slug is invalid: ${ repo }`);
}
if (!token) {
    lib_1.die('github authentication token is not defined, use --token <token> or set GH_TOKEN beforehand');
}
if (!tag) {
    lib_1.die('github release tag not defined, use --tag <tag> or set GH_TAG beforehand');
}
if (!fs.existsSync(output)) {
    if (!makeDir) {
        lib_1.die([
            `output path does not exist: ${ output }`,
            `use --make-dir to automatically create the path or create it beforehand`
        ]);
    } else {
        lib_1.ensureDirSync(output);
    }
} else {
}
if (!assets.length) {
    lib_1.die(`no assets provided for download. Use --asset or set GH_ASSET_NAME beforehand`);
}
console.log('\nConfiguration');
console.log('  github repository: ', repo);
console.log('  release tag:       ', tag);
console.log('  output folder:     ', output);
console.log('  unzip archives:    ', unzip ? chalk_1.default.green('yes') : chalk_1.default.gray('no'));
console.log('  target assets:     ', assets.join('\n                      '));
console.log('\nGetting list of available assets...');
const assetList = lib_1.curlAssetList({
    tag,
    repo,
    token
});
if (!assetList) {
    lib_1.die(`Couldn't retrieve asset list, check your configuration and token permissions`);
}
assetList.forEach(x => {
    console.log(`  → ${ x.name }`);
});
const targetAssets = assetList.filter(x => assets.includes(x.name));
const missingAssets = assets.filter(a => !targetAssets.find(ta => ta.name === a));
if (missingAssets.length) {
    lib_1.die([
        `Couldn't retrieve asset urls`,
        ...missingAssets.map(ma => `  → ${ ma }`)
    ]);
}
console.log(`\nDownloading assets...`);
targetAssets.forEach(({url, name}) => {
    const start = Date.now();
    const outputFile = path.join(output, name);
    console.log(`  → ${ name }`);
    const {size} = lib_1.curlAsset({
        token,
        url,
        outputFile
    });
    console.log(`    File created: ${ outputFile } (${ size } bytes, ${ lib_1.stringifyInterval(Date.now() - start) })`);
});
if (unzip) {
    console.log(`\nUnzipping assets...`);
    targetAssets.filter(x => x.name.endsWith('.zip')).forEach(({name}) => {
        const start = Date.now();
        console.log(`  → ${ name }`);
        const {outputFolder} = lib_1.unzipAsset({
            name,
            output
        });
        console.log(`    Unzipped into: ${ outputFolder } (${ lib_1.stringifyInterval(Date.now() - start) })`);
    });
}
console.log(chalk_1.default.green.bold(`\nAll done!`));
}
// default/lib.js
$fsx.f[1] =
function(module,exports){
var __importStar = this && this.__importStar || function (mod) {
    if (mod && mod.__esModule)
        return mod;
    var result = {};
    if (mod != null)
        for (var k in mod)
            if (Object.hasOwnProperty.call(mod, k))
                result[k] = mod[k];
    result['default'] = mod;
    return result;
};
var __importDefault = this && this.__importDefault || function (mod) {
    return mod && mod.__esModule ? mod : { 'default': mod };
};
Object.defineProperty(exports, '__esModule', { value: true });
const child_process_1 = $fsx.s('child_process');
const fs = __importStar($fsx.s('fs'));
const path = __importStar($fsx.s('path'));
const chalk_1 = __importDefault($fsx.r(4));
function makePrefix({token, repo}) {
    return `https://${ token }@api.github.com/repos/${ repo }/releases`;
}
function curlAssetList({tag, token, repo}) {
    const prefix = makePrefix({
        token,
        repo
    });
    const result = child_process_1.execSync(`curl -s ${ prefix }/tags/${ tag }`).toString();
    const {assets} = JSON.parse(result);
    return assets;
}
exports.curlAssetList = curlAssetList;
function curlAsset({token, url, outputFile}) {
    const tokenizedUrl = `https://${ token }@${ url.substr(8) }`;
    child_process_1.execSync(`curl -sL -H "Accept:application/octet-stream" -o "${ outputFile }" "${ tokenizedUrl }"`).toString();
    return {
        outputFile,
        size: fs.statSync(outputFile).size
    };
}
exports.curlAsset = curlAsset;
function ensureDirSync(dir) {
    fs.mkdirSync(dir, { recursive: true });
}
exports.ensureDirSync = ensureDirSync;
function unzipAsset({name, output}) {
    const outputFile = path.join(output, name);
    const outputFolder = path.join(output, path.basename(name, path.extname(name)));
    ensureDirSync(outputFolder);
    child_process_1.execSync(process.platform === 'win32' ? `tar -kxf "${ outputFile }" -C "${ outputFolder }"` : `unzip -o -d "${ outputFolder }" "${ outputFile }"`).toString();
    return { outputFolder };
}
exports.unzipAsset = unzipAsset;
function stringifyInterval(i) {
    if (i < 1000) {
        return `${ i }ms`;
    } else {
        return `${ Math.round(i / 1000) }s`;
    }
}
exports.stringifyInterval = stringifyInterval;
function die(messageOrMessages) {
    const messages = Array.isArray(messageOrMessages) ? messageOrMessages : [messageOrMessages];
    console.error(chalk_1.default.red(`\nFatal error`));
    messages.forEach(m => {
        console.error(m);
    });
    console.error('');
    process.exit(1);
}
exports.die = die;
}
// ansi-styles@4.2.1/index.js
$fsx.f[3] =
function(module){
const wrapAnsi16 = (fn, offset) => (...args) => {
    const code = fn(...args);
    return `\u001B[${ code + offset }m`;
};
const wrapAnsi256 = (fn, offset) => (...args) => {
    const code = fn(...args);
    return `\u001B[${ 38 + offset };5;${ code }m`;
};
const wrapAnsi16m = (fn, offset) => (...args) => {
    const rgb = fn(...args);
    return `\u001B[${ 38 + offset };2;${ rgb[0] };${ rgb[1] };${ rgb[2] }m`;
};
const ansi2ansi = n => n;
const rgb2rgb = (r, g, b) => [
    r,
    g,
    b
];
const setLazyProperty = (object, property, get) => {
    Object.defineProperty(object, property, {
        get: () => {
            const value = get();
            Object.defineProperty(object, property, {
                value,
                enumerable: true,
                configurable: true
            });
            return value;
        },
        enumerable: true,
        configurable: true
    });
};
let colorConvert;
const makeDynamicStyles = (wrap, targetSpace, identity, isBackground) => {
    if (colorConvert === undefined) {
        colorConvert = $fsx.r(7);
    }
    const offset = isBackground ? 10 : 0;
    const styles = {};
    for (const [sourceSpace, suite] of Object.entries(colorConvert)) {
        const name = sourceSpace === 'ansi16' ? 'ansi' : sourceSpace;
        if (sourceSpace === targetSpace) {
            styles[name] = wrap(identity, offset);
        } else if (typeof suite === 'object') {
            styles[name] = wrap(suite[targetSpace], offset);
        }
    }
    return styles;
};
function assembleStyles() {
    const codes = new Map();
    const styles = {
        modifier: {
            reset: [
                0,
                0
            ],
            bold: [
                1,
                22
            ],
            dim: [
                2,
                22
            ],
            italic: [
                3,
                23
            ],
            underline: [
                4,
                24
            ],
            inverse: [
                7,
                27
            ],
            hidden: [
                8,
                28
            ],
            strikethrough: [
                9,
                29
            ]
        },
        color: {
            black: [
                30,
                39
            ],
            red: [
                31,
                39
            ],
            green: [
                32,
                39
            ],
            yellow: [
                33,
                39
            ],
            blue: [
                34,
                39
            ],
            magenta: [
                35,
                39
            ],
            cyan: [
                36,
                39
            ],
            white: [
                37,
                39
            ],
            blackBright: [
                90,
                39
            ],
            redBright: [
                91,
                39
            ],
            greenBright: [
                92,
                39
            ],
            yellowBright: [
                93,
                39
            ],
            blueBright: [
                94,
                39
            ],
            magentaBright: [
                95,
                39
            ],
            cyanBright: [
                96,
                39
            ],
            whiteBright: [
                97,
                39
            ]
        },
        bgColor: {
            bgBlack: [
                40,
                49
            ],
            bgRed: [
                41,
                49
            ],
            bgGreen: [
                42,
                49
            ],
            bgYellow: [
                43,
                49
            ],
            bgBlue: [
                44,
                49
            ],
            bgMagenta: [
                45,
                49
            ],
            bgCyan: [
                46,
                49
            ],
            bgWhite: [
                47,
                49
            ],
            bgBlackBright: [
                100,
                49
            ],
            bgRedBright: [
                101,
                49
            ],
            bgGreenBright: [
                102,
                49
            ],
            bgYellowBright: [
                103,
                49
            ],
            bgBlueBright: [
                104,
                49
            ],
            bgMagentaBright: [
                105,
                49
            ],
            bgCyanBright: [
                106,
                49
            ],
            bgWhiteBright: [
                107,
                49
            ]
        }
    };
    styles.color.gray = styles.color.blackBright;
    styles.bgColor.bgGray = styles.bgColor.bgBlackBright;
    styles.color.grey = styles.color.blackBright;
    styles.bgColor.bgGrey = styles.bgColor.bgBlackBright;
    for (const [groupName, group] of Object.entries(styles)) {
        for (const [styleName, style] of Object.entries(group)) {
            styles[styleName] = {
                open: `\u001B[${ style[0] }m`,
                close: `\u001B[${ style[1] }m`
            };
            group[styleName] = styles[styleName];
            codes.set(style[0], style[1]);
        }
        Object.defineProperty(styles, groupName, {
            value: group,
            enumerable: false
        });
    }
    Object.defineProperty(styles, 'codes', {
        value: codes,
        enumerable: false
    });
    styles.color.close = '\x1B[39m';
    styles.bgColor.close = '\x1B[49m';
    setLazyProperty(styles.color, 'ansi', () => makeDynamicStyles(wrapAnsi16, 'ansi16', ansi2ansi, false));
    setLazyProperty(styles.color, 'ansi256', () => makeDynamicStyles(wrapAnsi256, 'ansi256', ansi2ansi, false));
    setLazyProperty(styles.color, 'ansi16m', () => makeDynamicStyles(wrapAnsi16m, 'rgb', rgb2rgb, false));
    setLazyProperty(styles.bgColor, 'ansi', () => makeDynamicStyles(wrapAnsi16, 'ansi16', ansi2ansi, true));
    setLazyProperty(styles.bgColor, 'ansi256', () => makeDynamicStyles(wrapAnsi256, 'ansi256', ansi2ansi, true));
    setLazyProperty(styles.bgColor, 'ansi16m', () => makeDynamicStyles(wrapAnsi16m, 'rgb', rgb2rgb, true));
    return styles;
}
Object.defineProperty(module, 'exports', {
    enumerable: true,
    get: assembleStyles
});
}
// chalk/source/index.js
$fsx.f[4] =
function(module,exports){
const ansiStyles = $fsx.r(3);
const {
    stdout: stdoutColor,
    stderr: stderrColor
} = $fsx.r(14);
const {stringReplaceAll, stringEncaseCRLFWithFirstIndex} = $fsx.r(5);
const levelMapping = [
    'ansi',
    'ansi',
    'ansi256',
    'ansi16m'
];
const styles = Object.create(null);
const applyOptions = (object, options = {}) => {
    if (options.level && !(Number.isInteger(options.level) && options.level >= 0 && options.level <= 3)) {
        throw new Error('The `level` option should be an integer from 0 to 3');
    }
    const colorLevel = stdoutColor ? stdoutColor.level : 0;
    object.level = options.level === undefined ? colorLevel : options.level;
};
class ChalkClass {
    constructor(options) {
        return chalkFactory(options);
    }
}
const chalkFactory = options => {
    const chalk = {};
    applyOptions(chalk, options);
    chalk.template = (...arguments_) => chalkTag(chalk.template, ...arguments_);
    Object.setPrototypeOf(chalk, Chalk.prototype);
    Object.setPrototypeOf(chalk.template, chalk);
    chalk.template.constructor = () => {
        throw new Error('`chalk.constructor()` is deprecated. Use `new chalk.Instance()` instead.');
    };
    chalk.template.Instance = ChalkClass;
    return chalk.template;
};
function Chalk(options) {
    return chalkFactory(options);
}
for (const [styleName, style] of Object.entries(ansiStyles)) {
    styles[styleName] = {
        get() {
            const builder = createBuilder(this, createStyler(style.open, style.close, this._styler), this._isEmpty);
            Object.defineProperty(this, styleName, { value: builder });
            return builder;
        }
    };
}
styles.visible = {
    get() {
        const builder = createBuilder(this, this._styler, true);
        Object.defineProperty(this, 'visible', { value: builder });
        return builder;
    }
};
const usedModels = [
    'rgb',
    'hex',
    'keyword',
    'hsl',
    'hsv',
    'hwb',
    'ansi',
    'ansi256'
];
for (const model of usedModels) {
    styles[model] = {
        get() {
            const {level} = this;
            return function (...arguments_) {
                const styler = createStyler(ansiStyles.color[levelMapping[level]][model](...arguments_), ansiStyles.color.close, this._styler);
                return createBuilder(this, styler, this._isEmpty);
            };
        }
    };
}
for (const model of usedModels) {
    const bgModel = 'bg' + model[0].toUpperCase() + model.slice(1);
    styles[bgModel] = {
        get() {
            const {level} = this;
            return function (...arguments_) {
                const styler = createStyler(ansiStyles.bgColor[levelMapping[level]][model](...arguments_), ansiStyles.bgColor.close, this._styler);
                return createBuilder(this, styler, this._isEmpty);
            };
        }
    };
}
const proto = Object.defineProperties(() => {
}, {
    ...styles,
    level: {
        enumerable: true,
        get() {
            return this._generator.level;
        },
        set(level) {
            this._generator.level = level;
        }
    }
});
const createStyler = (open, close, parent) => {
    let openAll;
    let closeAll;
    if (parent === undefined) {
        openAll = open;
        closeAll = close;
    } else {
        openAll = parent.openAll + open;
        closeAll = close + parent.closeAll;
    }
    return {
        open,
        close,
        openAll,
        closeAll,
        parent
    };
};
const createBuilder = (self, _styler, _isEmpty) => {
    const builder = (...arguments_) => {
        return applyStyle(builder, arguments_.length === 1 ? '' + arguments_[0] : arguments_.join(' '));
    };
    Object.setPrototypeOf(builder, proto);
    builder._generator = self;
    builder._styler = _styler;
    builder._isEmpty = _isEmpty;
    return builder;
};
const applyStyle = (self, string) => {
    if (self.level <= 0 || !string) {
        return self._isEmpty ? '' : string;
    }
    let styler = self._styler;
    if (styler === undefined) {
        return string;
    }
    const {openAll, closeAll} = styler;
    if (string.indexOf('\x1B') !== -1) {
        while (styler !== undefined) {
            string = stringReplaceAll(string, styler.close, styler.open);
            styler = styler.parent;
        }
    }
    const lfIndex = string.indexOf('\n');
    if (lfIndex !== -1) {
        string = stringEncaseCRLFWithFirstIndex(string, closeAll, openAll, lfIndex);
    }
    return openAll + string + closeAll;
};
let template;
const chalkTag = (chalk, ...strings) => {
    const [firstString] = strings;
    if (!Array.isArray(firstString)) {
        return strings.join(' ');
    }
    const arguments_ = strings.slice(1);
    const parts = [firstString.raw[0]];
    for (let i = 1; i < firstString.length; i++) {
        parts.push(String(arguments_[i - 1]).replace(/[{}\\]/g, '\\$&'), String(firstString.raw[i]));
    }
    if (template === undefined) {
        template = $fsx.r(6);
    }
    return template(chalk, parts.join(''));
};
Object.defineProperties(Chalk.prototype, styles);
const chalk = Chalk();
chalk.supportsColor = stdoutColor;
chalk.stderr = Chalk({ level: stderrColor ? stderrColor.level : 0 });
chalk.stderr.supportsColor = stderrColor;
module.exports = chalk;
}
// chalk/source/util.js
$fsx.f[5] =
function(module,exports){
const stringReplaceAll = (string, substring, replacer) => {
    let index = string.indexOf(substring);
    if (index === -1) {
        return string;
    }
    const substringLength = substring.length;
    let endIndex = 0;
    let returnValue = '';
    do {
        returnValue += string.substr(endIndex, index - endIndex) + substring + replacer;
        endIndex = index + substringLength;
        index = string.indexOf(substring, endIndex);
    } while (index !== -1);
    returnValue += string.substr(endIndex);
    return returnValue;
};
const stringEncaseCRLFWithFirstIndex = (string, prefix, postfix, index) => {
    let endIndex = 0;
    let returnValue = '';
    do {
        const gotCR = string[index - 1] === '\r';
        returnValue += string.substr(endIndex, (gotCR ? index - 1 : index) - endIndex) + prefix + (gotCR ? '\r\n' : '\n') + postfix;
        endIndex = index + 1;
        index = string.indexOf('\n', endIndex);
    } while (index !== -1);
    returnValue += string.substr(endIndex);
    return returnValue;
};
module.exports = {
    stringReplaceAll,
    stringEncaseCRLFWithFirstIndex
};
}
// chalk/source/templates.js
$fsx.f[6] =
function(module,exports){
const TEMPLATE_REGEX = /(?:\\(u(?:[a-f\d]{4}|\{[a-f\d]{1,6}\})|x[a-f\d]{2}|.))|(?:\{(~)?(\w+(?:\([^)]*\))?(?:\.\w+(?:\([^)]*\))?)*)(?:[ \t]|(?=\r?\n)))|(\})|((?:.|[\r\n\f])+?)/gi;
const STYLE_REGEX = /(?:^|\.)(\w+)(?:\(([^)]*)\))?/g;
const STRING_REGEX = /^(['"])((?:\\.|(?!\1)[^\\])*)\1$/;
const ESCAPE_REGEX = /\\(u(?:[a-f\d]{4}|{[a-f\d]{1,6}})|x[a-f\d]{2}|.)|([^\\])/gi;
const ESCAPES = new Map([
    [
        'n',
        '\n'
    ],
    [
        'r',
        '\r'
    ],
    [
        't',
        '\t'
    ],
    [
        'b',
        '\b'
    ],
    [
        'f',
        '\f'
    ],
    [
        'v',
        '\x0B'
    ],
    [
        '0',
        '\0'
    ],
    [
        '\\',
        '\\'
    ],
    [
        'e',
        '\x1B'
    ],
    [
        'a',
        '\x07'
    ]
]);
function unescape(c) {
    const u = c[0] === 'u';
    const bracket = c[1] === '{';
    if (u && !bracket && c.length === 5 || c[0] === 'x' && c.length === 3) {
        return String.fromCharCode(parseInt(c.slice(1), 16));
    }
    if (u && bracket) {
        return String.fromCodePoint(parseInt(c.slice(2, -1), 16));
    }
    return ESCAPES.get(c) || c;
}
function parseArguments(name, arguments_) {
    const results = [];
    const chunks = arguments_.trim().split(/\s*,\s*/g);
    let matches;
    for (const chunk of chunks) {
        const number = Number(chunk);
        if (!Number.isNaN(number)) {
            results.push(number);
        } else if (matches = chunk.match(STRING_REGEX)) {
            results.push(matches[2].replace(ESCAPE_REGEX, (m, escape, character) => escape ? unescape(escape) : character));
        } else {
            throw new Error(`Invalid Chalk template style argument: ${ chunk } (in style '${ name }')`);
        }
    }
    return results;
}
function parseStyle(style) {
    STYLE_REGEX.lastIndex = 0;
    const results = [];
    let matches;
    while ((matches = STYLE_REGEX.exec(style)) !== null) {
        const name = matches[1];
        if (matches[2]) {
            const args = parseArguments(name, matches[2]);
            results.push([name].concat(args));
        } else {
            results.push([name]);
        }
    }
    return results;
}
function buildStyle(chalk, styles) {
    const enabled = {};
    for (const layer of styles) {
        for (const style of layer.styles) {
            enabled[style[0]] = layer.inverse ? null : style.slice(1);
        }
    }
    let current = chalk;
    for (const [styleName, styles] of Object.entries(enabled)) {
        if (!Array.isArray(styles)) {
            continue;
        }
        if (!(styleName in current)) {
            throw new Error(`Unknown Chalk style: ${ styleName }`);
        }
        current = styles.length > 0 ? current[styleName](...styles) : current[styleName];
    }
    return current;
}
module.exports = (chalk, temporary) => {
    const styles = [];
    const chunks = [];
    let chunk = [];
    temporary.replace(TEMPLATE_REGEX, (m, escapeCharacter, inverse, style, close, character) => {
        if (escapeCharacter) {
            chunk.push(unescape(escapeCharacter));
        } else if (style) {
            const string = chunk.join('');
            chunk = [];
            chunks.push(styles.length === 0 ? string : buildStyle(chalk, styles)(string));
            styles.push({
                inverse,
                styles: parseStyle(style)
            });
        } else if (close) {
            if (styles.length === 0) {
                throw new Error('Found extraneous } in Chalk template literal');
            }
            chunks.push(buildStyle(chalk, styles)(chunk.join('')));
            chunk = [];
            styles.pop();
        } else {
            chunk.push(character);
        }
    });
    chunks.push(chunk.join(''));
    if (styles.length > 0) {
        const errMessage = `Chalk template literal is missing ${ styles.length } closing bracket${ styles.length === 1 ? '' : 's' } (\`}\`)`;
        throw new Error(errMessage);
    }
    return chunks.join('');
};
}
// color-convert@2.0.1/index.js
$fsx.f[7] =
function(module,exports){
const conversions = $fsx.r(8);
const route = $fsx.r(9);
const convert = {};
const models = Object.keys(conversions);
function wrapRaw(fn) {
    const wrappedFn = function (...args) {
        const arg0 = args[0];
        if (arg0 === undefined || arg0 === null) {
            return arg0;
        }
        if (arg0.length > 1) {
            args = arg0;
        }
        return fn(args);
    };
    if ('conversion' in fn) {
        wrappedFn.conversion = fn.conversion;
    }
    return wrappedFn;
}
function wrapRounded(fn) {
    const wrappedFn = function (...args) {
        const arg0 = args[0];
        if (arg0 === undefined || arg0 === null) {
            return arg0;
        }
        if (arg0.length > 1) {
            args = arg0;
        }
        const result = fn(args);
        if (typeof result === 'object') {
            for (let len = result.length, i = 0; i < len; i++) {
                result[i] = Math.round(result[i]);
            }
        }
        return result;
    };
    if ('conversion' in fn) {
        wrappedFn.conversion = fn.conversion;
    }
    return wrappedFn;
}
models.forEach(fromModel => {
    convert[fromModel] = {};
    Object.defineProperty(convert[fromModel], 'channels', { value: conversions[fromModel].channels });
    Object.defineProperty(convert[fromModel], 'labels', { value: conversions[fromModel].labels });
    const routes = route(fromModel);
    const routeModels = Object.keys(routes);
    routeModels.forEach(toModel => {
        const fn = routes[toModel];
        convert[fromModel][toModel] = wrapRounded(fn);
        convert[fromModel][toModel].raw = wrapRaw(fn);
    });
});
module.exports = convert;
}
// color-convert@2.0.1/conversions.js
$fsx.f[8] =
function(module,exports){
const cssKeywords = $fsx.r(10);
const reverseKeywords = {};
for (const key of Object.keys(cssKeywords)) {
    reverseKeywords[cssKeywords[key]] = key;
}
const convert = {
    rgb: {
        channels: 3,
        labels: 'rgb'
    },
    hsl: {
        channels: 3,
        labels: 'hsl'
    },
    hsv: {
        channels: 3,
        labels: 'hsv'
    },
    hwb: {
        channels: 3,
        labels: 'hwb'
    },
    cmyk: {
        channels: 4,
        labels: 'cmyk'
    },
    xyz: {
        channels: 3,
        labels: 'xyz'
    },
    lab: {
        channels: 3,
        labels: 'lab'
    },
    lch: {
        channels: 3,
        labels: 'lch'
    },
    hex: {
        channels: 1,
        labels: ['hex']
    },
    keyword: {
        channels: 1,
        labels: ['keyword']
    },
    ansi16: {
        channels: 1,
        labels: ['ansi16']
    },
    ansi256: {
        channels: 1,
        labels: ['ansi256']
    },
    hcg: {
        channels: 3,
        labels: [
            'h',
            'c',
            'g'
        ]
    },
    apple: {
        channels: 3,
        labels: [
            'r16',
            'g16',
            'b16'
        ]
    },
    gray: {
        channels: 1,
        labels: ['gray']
    }
};
module.exports = convert;
for (const model of Object.keys(convert)) {
    if (!('channels' in convert[model])) {
        throw new Error('missing channels property: ' + model);
    }
    if (!('labels' in convert[model])) {
        throw new Error('missing channel labels property: ' + model);
    }
    if (convert[model].labels.length !== convert[model].channels) {
        throw new Error('channel and label counts mismatch: ' + model);
    }
    const {channels, labels} = convert[model];
    delete convert[model].channels;
    delete convert[model].labels;
    Object.defineProperty(convert[model], 'channels', { value: channels });
    Object.defineProperty(convert[model], 'labels', { value: labels });
}
convert.rgb.hsl = function (rgb) {
    const r = rgb[0] / 255;
    const g = rgb[1] / 255;
    const b = rgb[2] / 255;
    const min = Math.min(r, g, b);
    const max = Math.max(r, g, b);
    const delta = max - min;
    let h;
    let s;
    if (max === min) {
        h = 0;
    } else if (r === max) {
        h = (g - b) / delta;
    } else if (g === max) {
        h = 2 + (b - r) / delta;
    } else if (b === max) {
        h = 4 + (r - g) / delta;
    }
    h = Math.min(h * 60, 360);
    if (h < 0) {
        h += 360;
    }
    const l = (min + max) / 2;
    if (max === min) {
        s = 0;
    } else if (l <= 0.5) {
        s = delta / (max + min);
    } else {
        s = delta / (2 - max - min);
    }
    return [
        h,
        s * 100,
        l * 100
    ];
};
convert.rgb.hsv = function (rgb) {
    let rdif;
    let gdif;
    let bdif;
    let h;
    let s;
    const r = rgb[0] / 255;
    const g = rgb[1] / 255;
    const b = rgb[2] / 255;
    const v = Math.max(r, g, b);
    const diff = v - Math.min(r, g, b);
    const diffc = function (c) {
        return (v - c) / 6 / diff + 1 / 2;
    };
    if (diff === 0) {
        h = 0;
        s = 0;
    } else {
        s = diff / v;
        rdif = diffc(r);
        gdif = diffc(g);
        bdif = diffc(b);
        if (r === v) {
            h = bdif - gdif;
        } else if (g === v) {
            h = 1 / 3 + rdif - bdif;
        } else if (b === v) {
            h = 2 / 3 + gdif - rdif;
        }
        if (h < 0) {
            h += 1;
        } else if (h > 1) {
            h -= 1;
        }
    }
    return [
        h * 360,
        s * 100,
        v * 100
    ];
};
convert.rgb.hwb = function (rgb) {
    const r = rgb[0];
    const g = rgb[1];
    let b = rgb[2];
    const h = convert.rgb.hsl(rgb)[0];
    const w = 1 / 255 * Math.min(r, Math.min(g, b));
    b = 1 - 1 / 255 * Math.max(r, Math.max(g, b));
    return [
        h,
        w * 100,
        b * 100
    ];
};
convert.rgb.cmyk = function (rgb) {
    const r = rgb[0] / 255;
    const g = rgb[1] / 255;
    const b = rgb[2] / 255;
    const k = Math.min(1 - r, 1 - g, 1 - b);
    const c = (1 - r - k) / (1 - k) || 0;
    const m = (1 - g - k) / (1 - k) || 0;
    const y = (1 - b - k) / (1 - k) || 0;
    return [
        c * 100,
        m * 100,
        y * 100,
        k * 100
    ];
};
function comparativeDistance(x, y) {
    return (x[0] - y[0]) ** 2 + (x[1] - y[1]) ** 2 + (x[2] - y[2]) ** 2;
}
convert.rgb.keyword = function (rgb) {
    const reversed = reverseKeywords[rgb];
    if (reversed) {
        return reversed;
    }
    let currentClosestDistance = Infinity;
    let currentClosestKeyword;
    for (const keyword of Object.keys(cssKeywords)) {
        const value = cssKeywords[keyword];
        const distance = comparativeDistance(rgb, value);
        if (distance < currentClosestDistance) {
            currentClosestDistance = distance;
            currentClosestKeyword = keyword;
        }
    }
    return currentClosestKeyword;
};
convert.keyword.rgb = function (keyword) {
    return cssKeywords[keyword];
};
convert.rgb.xyz = function (rgb) {
    let r = rgb[0] / 255;
    let g = rgb[1] / 255;
    let b = rgb[2] / 255;
    r = r > 0.04045 ? ((r + 0.055) / 1.055) ** 2.4 : r / 12.92;
    g = g > 0.04045 ? ((g + 0.055) / 1.055) ** 2.4 : g / 12.92;
    b = b > 0.04045 ? ((b + 0.055) / 1.055) ** 2.4 : b / 12.92;
    const x = r * 0.4124 + g * 0.3576 + b * 0.1805;
    const y = r * 0.2126 + g * 0.7152 + b * 0.0722;
    const z = r * 0.0193 + g * 0.1192 + b * 0.9505;
    return [
        x * 100,
        y * 100,
        z * 100
    ];
};
convert.rgb.lab = function (rgb) {
    const xyz = convert.rgb.xyz(rgb);
    let x = xyz[0];
    let y = xyz[1];
    let z = xyz[2];
    x /= 95.047;
    y /= 100;
    z /= 108.883;
    x = x > 0.008856 ? x ** (1 / 3) : 7.787 * x + 16 / 116;
    y = y > 0.008856 ? y ** (1 / 3) : 7.787 * y + 16 / 116;
    z = z > 0.008856 ? z ** (1 / 3) : 7.787 * z + 16 / 116;
    const l = 116 * y - 16;
    const a = 500 * (x - y);
    const b = 200 * (y - z);
    return [
        l,
        a,
        b
    ];
};
convert.hsl.rgb = function (hsl) {
    const h = hsl[0] / 360;
    const s = hsl[1] / 100;
    const l = hsl[2] / 100;
    let t2;
    let t3;
    let val;
    if (s === 0) {
        val = l * 255;
        return [
            val,
            val,
            val
        ];
    }
    if (l < 0.5) {
        t2 = l * (1 + s);
    } else {
        t2 = l + s - l * s;
    }
    const t1 = 2 * l - t2;
    const rgb = [
        0,
        0,
        0
    ];
    for (let i = 0; i < 3; i++) {
        t3 = h + 1 / 3 * -(i - 1);
        if (t3 < 0) {
            t3++;
        }
        if (t3 > 1) {
            t3--;
        }
        if (6 * t3 < 1) {
            val = t1 + (t2 - t1) * 6 * t3;
        } else if (2 * t3 < 1) {
            val = t2;
        } else if (3 * t3 < 2) {
            val = t1 + (t2 - t1) * (2 / 3 - t3) * 6;
        } else {
            val = t1;
        }
        rgb[i] = val * 255;
    }
    return rgb;
};
convert.hsl.hsv = function (hsl) {
    const h = hsl[0];
    let s = hsl[1] / 100;
    let l = hsl[2] / 100;
    let smin = s;
    const lmin = Math.max(l, 0.01);
    l *= 2;
    s *= l <= 1 ? l : 2 - l;
    smin *= lmin <= 1 ? lmin : 2 - lmin;
    const v = (l + s) / 2;
    const sv = l === 0 ? 2 * smin / (lmin + smin) : 2 * s / (l + s);
    return [
        h,
        sv * 100,
        v * 100
    ];
};
convert.hsv.rgb = function (hsv) {
    const h = hsv[0] / 60;
    const s = hsv[1] / 100;
    let v = hsv[2] / 100;
    const hi = Math.floor(h) % 6;
    const f = h - Math.floor(h);
    const p = 255 * v * (1 - s);
    const q = 255 * v * (1 - s * f);
    const t = 255 * v * (1 - s * (1 - f));
    v *= 255;
    switch (hi) {
    case 0:
        return [
            v,
            t,
            p
        ];
    case 1:
        return [
            q,
            v,
            p
        ];
    case 2:
        return [
            p,
            v,
            t
        ];
    case 3:
        return [
            p,
            q,
            v
        ];
    case 4:
        return [
            t,
            p,
            v
        ];
    case 5:
        return [
            v,
            p,
            q
        ];
    }
};
convert.hsv.hsl = function (hsv) {
    const h = hsv[0];
    const s = hsv[1] / 100;
    const v = hsv[2] / 100;
    const vmin = Math.max(v, 0.01);
    let sl;
    let l;
    l = (2 - s) * v;
    const lmin = (2 - s) * vmin;
    sl = s * vmin;
    sl /= lmin <= 1 ? lmin : 2 - lmin;
    sl = sl || 0;
    l /= 2;
    return [
        h,
        sl * 100,
        l * 100
    ];
};
convert.hwb.rgb = function (hwb) {
    const h = hwb[0] / 360;
    let wh = hwb[1] / 100;
    let bl = hwb[2] / 100;
    const ratio = wh + bl;
    let f;
    if (ratio > 1) {
        wh /= ratio;
        bl /= ratio;
    }
    const i = Math.floor(6 * h);
    const v = 1 - bl;
    f = 6 * h - i;
    if ((i & 1) !== 0) {
        f = 1 - f;
    }
    const n = wh + f * (v - wh);
    let r;
    let g;
    let b;
    switch (i) {
    default:
    case 6:
    case 0:
        r = v;
        g = n;
        b = wh;
        break;
    case 1:
        r = n;
        g = v;
        b = wh;
        break;
    case 2:
        r = wh;
        g = v;
        b = n;
        break;
    case 3:
        r = wh;
        g = n;
        b = v;
        break;
    case 4:
        r = n;
        g = wh;
        b = v;
        break;
    case 5:
        r = v;
        g = wh;
        b = n;
        break;
    }
    return [
        r * 255,
        g * 255,
        b * 255
    ];
};
convert.cmyk.rgb = function (cmyk) {
    const c = cmyk[0] / 100;
    const m = cmyk[1] / 100;
    const y = cmyk[2] / 100;
    const k = cmyk[3] / 100;
    const r = 1 - Math.min(1, c * (1 - k) + k);
    const g = 1 - Math.min(1, m * (1 - k) + k);
    const b = 1 - Math.min(1, y * (1 - k) + k);
    return [
        r * 255,
        g * 255,
        b * 255
    ];
};
convert.xyz.rgb = function (xyz) {
    const x = xyz[0] / 100;
    const y = xyz[1] / 100;
    const z = xyz[2] / 100;
    let r;
    let g;
    let b;
    r = x * 3.2406 + y * -1.5372 + z * -0.4986;
    g = x * -0.9689 + y * 1.8758 + z * 0.0415;
    b = x * 0.0557 + y * -0.204 + z * 1.057;
    r = r > 0.0031308 ? 1.055 * r ** (1 / 2.4) - 0.055 : r * 12.92;
    g = g > 0.0031308 ? 1.055 * g ** (1 / 2.4) - 0.055 : g * 12.92;
    b = b > 0.0031308 ? 1.055 * b ** (1 / 2.4) - 0.055 : b * 12.92;
    r = Math.min(Math.max(0, r), 1);
    g = Math.min(Math.max(0, g), 1);
    b = Math.min(Math.max(0, b), 1);
    return [
        r * 255,
        g * 255,
        b * 255
    ];
};
convert.xyz.lab = function (xyz) {
    let x = xyz[0];
    let y = xyz[1];
    let z = xyz[2];
    x /= 95.047;
    y /= 100;
    z /= 108.883;
    x = x > 0.008856 ? x ** (1 / 3) : 7.787 * x + 16 / 116;
    y = y > 0.008856 ? y ** (1 / 3) : 7.787 * y + 16 / 116;
    z = z > 0.008856 ? z ** (1 / 3) : 7.787 * z + 16 / 116;
    const l = 116 * y - 16;
    const a = 500 * (x - y);
    const b = 200 * (y - z);
    return [
        l,
        a,
        b
    ];
};
convert.lab.xyz = function (lab) {
    const l = lab[0];
    const a = lab[1];
    const b = lab[2];
    let x;
    let y;
    let z;
    y = (l + 16) / 116;
    x = a / 500 + y;
    z = y - b / 200;
    const y2 = y ** 3;
    const x2 = x ** 3;
    const z2 = z ** 3;
    y = y2 > 0.008856 ? y2 : (y - 16 / 116) / 7.787;
    x = x2 > 0.008856 ? x2 : (x - 16 / 116) / 7.787;
    z = z2 > 0.008856 ? z2 : (z - 16 / 116) / 7.787;
    x *= 95.047;
    y *= 100;
    z *= 108.883;
    return [
        x,
        y,
        z
    ];
};
convert.lab.lch = function (lab) {
    const l = lab[0];
    const a = lab[1];
    const b = lab[2];
    let h;
    const hr = Math.atan2(b, a);
    h = hr * 360 / 2 / Math.PI;
    if (h < 0) {
        h += 360;
    }
    const c = Math.sqrt(a * a + b * b);
    return [
        l,
        c,
        h
    ];
};
convert.lch.lab = function (lch) {
    const l = lch[0];
    const c = lch[1];
    const h = lch[2];
    const hr = h / 360 * 2 * Math.PI;
    const a = c * Math.cos(hr);
    const b = c * Math.sin(hr);
    return [
        l,
        a,
        b
    ];
};
convert.rgb.ansi16 = function (args, saturation = null) {
    const [r, g, b] = args;
    let value = saturation === null ? convert.rgb.hsv(args)[2] : saturation;
    value = Math.round(value / 50);
    if (value === 0) {
        return 30;
    }
    let ansi = 30 + (Math.round(b / 255) << 2 | Math.round(g / 255) << 1 | Math.round(r / 255));
    if (value === 2) {
        ansi += 60;
    }
    return ansi;
};
convert.hsv.ansi16 = function (args) {
    return convert.rgb.ansi16(convert.hsv.rgb(args), args[2]);
};
convert.rgb.ansi256 = function (args) {
    const r = args[0];
    const g = args[1];
    const b = args[2];
    if (r === g && g === b) {
        if (r < 8) {
            return 16;
        }
        if (r > 248) {
            return 231;
        }
        return Math.round((r - 8) / 247 * 24) + 232;
    }
    const ansi = 16 + 36 * Math.round(r / 255 * 5) + 6 * Math.round(g / 255 * 5) + Math.round(b / 255 * 5);
    return ansi;
};
convert.ansi16.rgb = function (args) {
    let color = args % 10;
    if (color === 0 || color === 7) {
        if (args > 50) {
            color += 3.5;
        }
        color = color / 10.5 * 255;
        return [
            color,
            color,
            color
        ];
    }
    const mult = (~~(args > 50) + 1) * 0.5;
    const r = (color & 1) * mult * 255;
    const g = (color >> 1 & 1) * mult * 255;
    const b = (color >> 2 & 1) * mult * 255;
    return [
        r,
        g,
        b
    ];
};
convert.ansi256.rgb = function (args) {
    if (args >= 232) {
        const c = (args - 232) * 10 + 8;
        return [
            c,
            c,
            c
        ];
    }
    args -= 16;
    let rem;
    const r = Math.floor(args / 36) / 5 * 255;
    const g = Math.floor((rem = args % 36) / 6) / 5 * 255;
    const b = rem % 6 / 5 * 255;
    return [
        r,
        g,
        b
    ];
};
convert.rgb.hex = function (args) {
    const integer = ((Math.round(args[0]) & 255) << 16) + ((Math.round(args[1]) & 255) << 8) + (Math.round(args[2]) & 255);
    const string = integer.toString(16).toUpperCase();
    return '000000'.substring(string.length) + string;
};
convert.hex.rgb = function (args) {
    const match = args.toString(16).match(/[a-f0-9]{6}|[a-f0-9]{3}/i);
    if (!match) {
        return [
            0,
            0,
            0
        ];
    }
    let colorString = match[0];
    if (match[0].length === 3) {
        colorString = colorString.split('').map(char => {
            return char + char;
        }).join('');
    }
    const integer = parseInt(colorString, 16);
    const r = integer >> 16 & 255;
    const g = integer >> 8 & 255;
    const b = integer & 255;
    return [
        r,
        g,
        b
    ];
};
convert.rgb.hcg = function (rgb) {
    const r = rgb[0] / 255;
    const g = rgb[1] / 255;
    const b = rgb[2] / 255;
    const max = Math.max(Math.max(r, g), b);
    const min = Math.min(Math.min(r, g), b);
    const chroma = max - min;
    let grayscale;
    let hue;
    if (chroma < 1) {
        grayscale = min / (1 - chroma);
    } else {
        grayscale = 0;
    }
    if (chroma <= 0) {
        hue = 0;
    } else if (max === r) {
        hue = (g - b) / chroma % 6;
    } else if (max === g) {
        hue = 2 + (b - r) / chroma;
    } else {
        hue = 4 + (r - g) / chroma;
    }
    hue /= 6;
    hue %= 1;
    return [
        hue * 360,
        chroma * 100,
        grayscale * 100
    ];
};
convert.hsl.hcg = function (hsl) {
    const s = hsl[1] / 100;
    const l = hsl[2] / 100;
    const c = l < 0.5 ? 2 * s * l : 2 * s * (1 - l);
    let f = 0;
    if (c < 1) {
        f = (l - 0.5 * c) / (1 - c);
    }
    return [
        hsl[0],
        c * 100,
        f * 100
    ];
};
convert.hsv.hcg = function (hsv) {
    const s = hsv[1] / 100;
    const v = hsv[2] / 100;
    const c = s * v;
    let f = 0;
    if (c < 1) {
        f = (v - c) / (1 - c);
    }
    return [
        hsv[0],
        c * 100,
        f * 100
    ];
};
convert.hcg.rgb = function (hcg) {
    const h = hcg[0] / 360;
    const c = hcg[1] / 100;
    const g = hcg[2] / 100;
    if (c === 0) {
        return [
            g * 255,
            g * 255,
            g * 255
        ];
    }
    const pure = [
        0,
        0,
        0
    ];
    const hi = h % 1 * 6;
    const v = hi % 1;
    const w = 1 - v;
    let mg = 0;
    switch (Math.floor(hi)) {
    case 0:
        pure[0] = 1;
        pure[1] = v;
        pure[2] = 0;
        break;
    case 1:
        pure[0] = w;
        pure[1] = 1;
        pure[2] = 0;
        break;
    case 2:
        pure[0] = 0;
        pure[1] = 1;
        pure[2] = v;
        break;
    case 3:
        pure[0] = 0;
        pure[1] = w;
        pure[2] = 1;
        break;
    case 4:
        pure[0] = v;
        pure[1] = 0;
        pure[2] = 1;
        break;
    default:
        pure[0] = 1;
        pure[1] = 0;
        pure[2] = w;
    }
    mg = (1 - c) * g;
    return [
        (c * pure[0] + mg) * 255,
        (c * pure[1] + mg) * 255,
        (c * pure[2] + mg) * 255
    ];
};
convert.hcg.hsv = function (hcg) {
    const c = hcg[1] / 100;
    const g = hcg[2] / 100;
    const v = c + g * (1 - c);
    let f = 0;
    if (v > 0) {
        f = c / v;
    }
    return [
        hcg[0],
        f * 100,
        v * 100
    ];
};
convert.hcg.hsl = function (hcg) {
    const c = hcg[1] / 100;
    const g = hcg[2] / 100;
    const l = g * (1 - c) + 0.5 * c;
    let s = 0;
    if (l > 0 && l < 0.5) {
        s = c / (2 * l);
    } else if (l >= 0.5 && l < 1) {
        s = c / (2 * (1 - l));
    }
    return [
        hcg[0],
        s * 100,
        l * 100
    ];
};
convert.hcg.hwb = function (hcg) {
    const c = hcg[1] / 100;
    const g = hcg[2] / 100;
    const v = c + g * (1 - c);
    return [
        hcg[0],
        (v - c) * 100,
        (1 - v) * 100
    ];
};
convert.hwb.hcg = function (hwb) {
    const w = hwb[1] / 100;
    const b = hwb[2] / 100;
    const v = 1 - b;
    const c = v - w;
    let g = 0;
    if (c < 1) {
        g = (v - c) / (1 - c);
    }
    return [
        hwb[0],
        c * 100,
        g * 100
    ];
};
convert.apple.rgb = function (apple) {
    return [
        apple[0] / 65535 * 255,
        apple[1] / 65535 * 255,
        apple[2] / 65535 * 255
    ];
};
convert.rgb.apple = function (rgb) {
    return [
        rgb[0] / 255 * 65535,
        rgb[1] / 255 * 65535,
        rgb[2] / 255 * 65535
    ];
};
convert.gray.rgb = function (args) {
    return [
        args[0] / 100 * 255,
        args[0] / 100 * 255,
        args[0] / 100 * 255
    ];
};
convert.gray.hsl = function (args) {
    return [
        0,
        0,
        args[0]
    ];
};
convert.gray.hsv = convert.gray.hsl;
convert.gray.hwb = function (gray) {
    return [
        0,
        100,
        gray[0]
    ];
};
convert.gray.cmyk = function (gray) {
    return [
        0,
        0,
        0,
        gray[0]
    ];
};
convert.gray.lab = function (gray) {
    return [
        gray[0],
        0,
        0
    ];
};
convert.gray.hex = function (gray) {
    const val = Math.round(gray[0] / 100 * 255) & 255;
    const integer = (val << 16) + (val << 8) + val;
    const string = integer.toString(16).toUpperCase();
    return '000000'.substring(string.length) + string;
};
convert.rgb.gray = function (rgb) {
    const val = (rgb[0] + rgb[1] + rgb[2]) / 3;
    return [val / 255 * 100];
};
}
// color-convert@2.0.1/route.js
$fsx.f[9] =
function(module,exports){
const conversions = $fsx.r(8);
function buildGraph() {
    const graph = {};
    const models = Object.keys(conversions);
    for (let len = models.length, i = 0; i < len; i++) {
        graph[models[i]] = {
            distance: -1,
            parent: null
        };
    }
    return graph;
}
function deriveBFS(fromModel) {
    const graph = buildGraph();
    const queue = [fromModel];
    graph[fromModel].distance = 0;
    while (queue.length) {
        const current = queue.pop();
        const adjacents = Object.keys(conversions[current]);
        for (let len = adjacents.length, i = 0; i < len; i++) {
            const adjacent = adjacents[i];
            const node = graph[adjacent];
            if (node.distance === -1) {
                node.distance = graph[current].distance + 1;
                node.parent = current;
                queue.unshift(adjacent);
            }
        }
    }
    return graph;
}
function link(from, to) {
    return function (args) {
        return to(from(args));
    };
}
function wrapConversion(toModel, graph) {
    const path = [
        graph[toModel].parent,
        toModel
    ];
    let fn = conversions[graph[toModel].parent][toModel];
    let cur = graph[toModel].parent;
    while (graph[cur].parent) {
        path.unshift(graph[cur].parent);
        fn = link(conversions[graph[cur].parent][cur], fn);
        cur = graph[cur].parent;
    }
    fn.conversion = path;
    return fn;
}
module.exports = function (fromModel) {
    const graph = deriveBFS(fromModel);
    const conversion = {};
    const models = Object.keys(graph);
    for (let len = models.length, i = 0; i < len; i++) {
        const toModel = models[i];
        const node = graph[toModel];
        if (node.parent === null) {
            continue;
        }
        conversion[toModel] = wrapConversion(toModel, graph);
    }
    return conversion;
};
}
// color-name@1.1.4/index.js
$fsx.f[10] =
function(module,exports){
module.exports = {
    'aliceblue': [
        240,
        248,
        255
    ],
    'antiquewhite': [
        250,
        235,
        215
    ],
    'aqua': [
        0,
        255,
        255
    ],
    'aquamarine': [
        127,
        255,
        212
    ],
    'azure': [
        240,
        255,
        255
    ],
    'beige': [
        245,
        245,
        220
    ],
    'bisque': [
        255,
        228,
        196
    ],
    'black': [
        0,
        0,
        0
    ],
    'blanchedalmond': [
        255,
        235,
        205
    ],
    'blue': [
        0,
        0,
        255
    ],
    'blueviolet': [
        138,
        43,
        226
    ],
    'brown': [
        165,
        42,
        42
    ],
    'burlywood': [
        222,
        184,
        135
    ],
    'cadetblue': [
        95,
        158,
        160
    ],
    'chartreuse': [
        127,
        255,
        0
    ],
    'chocolate': [
        210,
        105,
        30
    ],
    'coral': [
        255,
        127,
        80
    ],
    'cornflowerblue': [
        100,
        149,
        237
    ],
    'cornsilk': [
        255,
        248,
        220
    ],
    'crimson': [
        220,
        20,
        60
    ],
    'cyan': [
        0,
        255,
        255
    ],
    'darkblue': [
        0,
        0,
        139
    ],
    'darkcyan': [
        0,
        139,
        139
    ],
    'darkgoldenrod': [
        184,
        134,
        11
    ],
    'darkgray': [
        169,
        169,
        169
    ],
    'darkgreen': [
        0,
        100,
        0
    ],
    'darkgrey': [
        169,
        169,
        169
    ],
    'darkkhaki': [
        189,
        183,
        107
    ],
    'darkmagenta': [
        139,
        0,
        139
    ],
    'darkolivegreen': [
        85,
        107,
        47
    ],
    'darkorange': [
        255,
        140,
        0
    ],
    'darkorchid': [
        153,
        50,
        204
    ],
    'darkred': [
        139,
        0,
        0
    ],
    'darksalmon': [
        233,
        150,
        122
    ],
    'darkseagreen': [
        143,
        188,
        143
    ],
    'darkslateblue': [
        72,
        61,
        139
    ],
    'darkslategray': [
        47,
        79,
        79
    ],
    'darkslategrey': [
        47,
        79,
        79
    ],
    'darkturquoise': [
        0,
        206,
        209
    ],
    'darkviolet': [
        148,
        0,
        211
    ],
    'deeppink': [
        255,
        20,
        147
    ],
    'deepskyblue': [
        0,
        191,
        255
    ],
    'dimgray': [
        105,
        105,
        105
    ],
    'dimgrey': [
        105,
        105,
        105
    ],
    'dodgerblue': [
        30,
        144,
        255
    ],
    'firebrick': [
        178,
        34,
        34
    ],
    'floralwhite': [
        255,
        250,
        240
    ],
    'forestgreen': [
        34,
        139,
        34
    ],
    'fuchsia': [
        255,
        0,
        255
    ],
    'gainsboro': [
        220,
        220,
        220
    ],
    'ghostwhite': [
        248,
        248,
        255
    ],
    'gold': [
        255,
        215,
        0
    ],
    'goldenrod': [
        218,
        165,
        32
    ],
    'gray': [
        128,
        128,
        128
    ],
    'green': [
        0,
        128,
        0
    ],
    'greenyellow': [
        173,
        255,
        47
    ],
    'grey': [
        128,
        128,
        128
    ],
    'honeydew': [
        240,
        255,
        240
    ],
    'hotpink': [
        255,
        105,
        180
    ],
    'indianred': [
        205,
        92,
        92
    ],
    'indigo': [
        75,
        0,
        130
    ],
    'ivory': [
        255,
        255,
        240
    ],
    'khaki': [
        240,
        230,
        140
    ],
    'lavender': [
        230,
        230,
        250
    ],
    'lavenderblush': [
        255,
        240,
        245
    ],
    'lawngreen': [
        124,
        252,
        0
    ],
    'lemonchiffon': [
        255,
        250,
        205
    ],
    'lightblue': [
        173,
        216,
        230
    ],
    'lightcoral': [
        240,
        128,
        128
    ],
    'lightcyan': [
        224,
        255,
        255
    ],
    'lightgoldenrodyellow': [
        250,
        250,
        210
    ],
    'lightgray': [
        211,
        211,
        211
    ],
    'lightgreen': [
        144,
        238,
        144
    ],
    'lightgrey': [
        211,
        211,
        211
    ],
    'lightpink': [
        255,
        182,
        193
    ],
    'lightsalmon': [
        255,
        160,
        122
    ],
    'lightseagreen': [
        32,
        178,
        170
    ],
    'lightskyblue': [
        135,
        206,
        250
    ],
    'lightslategray': [
        119,
        136,
        153
    ],
    'lightslategrey': [
        119,
        136,
        153
    ],
    'lightsteelblue': [
        176,
        196,
        222
    ],
    'lightyellow': [
        255,
        255,
        224
    ],
    'lime': [
        0,
        255,
        0
    ],
    'limegreen': [
        50,
        205,
        50
    ],
    'linen': [
        250,
        240,
        230
    ],
    'magenta': [
        255,
        0,
        255
    ],
    'maroon': [
        128,
        0,
        0
    ],
    'mediumaquamarine': [
        102,
        205,
        170
    ],
    'mediumblue': [
        0,
        0,
        205
    ],
    'mediumorchid': [
        186,
        85,
        211
    ],
    'mediumpurple': [
        147,
        112,
        219
    ],
    'mediumseagreen': [
        60,
        179,
        113
    ],
    'mediumslateblue': [
        123,
        104,
        238
    ],
    'mediumspringgreen': [
        0,
        250,
        154
    ],
    'mediumturquoise': [
        72,
        209,
        204
    ],
    'mediumvioletred': [
        199,
        21,
        133
    ],
    'midnightblue': [
        25,
        25,
        112
    ],
    'mintcream': [
        245,
        255,
        250
    ],
    'mistyrose': [
        255,
        228,
        225
    ],
    'moccasin': [
        255,
        228,
        181
    ],
    'navajowhite': [
        255,
        222,
        173
    ],
    'navy': [
        0,
        0,
        128
    ],
    'oldlace': [
        253,
        245,
        230
    ],
    'olive': [
        128,
        128,
        0
    ],
    'olivedrab': [
        107,
        142,
        35
    ],
    'orange': [
        255,
        165,
        0
    ],
    'orangered': [
        255,
        69,
        0
    ],
    'orchid': [
        218,
        112,
        214
    ],
    'palegoldenrod': [
        238,
        232,
        170
    ],
    'palegreen': [
        152,
        251,
        152
    ],
    'paleturquoise': [
        175,
        238,
        238
    ],
    'palevioletred': [
        219,
        112,
        147
    ],
    'papayawhip': [
        255,
        239,
        213
    ],
    'peachpuff': [
        255,
        218,
        185
    ],
    'peru': [
        205,
        133,
        63
    ],
    'pink': [
        255,
        192,
        203
    ],
    'plum': [
        221,
        160,
        221
    ],
    'powderblue': [
        176,
        224,
        230
    ],
    'purple': [
        128,
        0,
        128
    ],
    'rebeccapurple': [
        102,
        51,
        153
    ],
    'red': [
        255,
        0,
        0
    ],
    'rosybrown': [
        188,
        143,
        143
    ],
    'royalblue': [
        65,
        105,
        225
    ],
    'saddlebrown': [
        139,
        69,
        19
    ],
    'salmon': [
        250,
        128,
        114
    ],
    'sandybrown': [
        244,
        164,
        96
    ],
    'seagreen': [
        46,
        139,
        87
    ],
    'seashell': [
        255,
        245,
        238
    ],
    'sienna': [
        160,
        82,
        45
    ],
    'silver': [
        192,
        192,
        192
    ],
    'skyblue': [
        135,
        206,
        235
    ],
    'slateblue': [
        106,
        90,
        205
    ],
    'slategray': [
        112,
        128,
        144
    ],
    'slategrey': [
        112,
        128,
        144
    ],
    'snow': [
        255,
        250,
        250
    ],
    'springgreen': [
        0,
        255,
        127
    ],
    'steelblue': [
        70,
        130,
        180
    ],
    'tan': [
        210,
        180,
        140
    ],
    'teal': [
        0,
        128,
        128
    ],
    'thistle': [
        216,
        191,
        216
    ],
    'tomato': [
        255,
        99,
        71
    ],
    'turquoise': [
        64,
        224,
        208
    ],
    'violet': [
        238,
        130,
        238
    ],
    'wheat': [
        245,
        222,
        179
    ],
    'white': [
        255,
        255,
        255
    ],
    'whitesmoke': [
        245,
        245,
        245
    ],
    'yellow': [
        255,
        255,
        0
    ],
    'yellowgreen': [
        154,
        205,
        50
    ]
};
}
// commander/index.js
$fsx.f[11] =
function(module,exports){
const EventEmitter = $fsx.s('events').EventEmitter;
const spawn = $fsx.s('child_process').spawn;
const path = $fsx.s('path');
const fs = $fsx.s('fs');
class Option {
    constructor(flags, description) {
        this.flags = flags;
        this.required = flags.indexOf('<') >= 0;
        this.optional = flags.indexOf('[') >= 0;
        this.mandatory = false;
        this.negate = flags.indexOf('-no-') !== -1;
        const flagParts = flags.split(/[ ,|]+/);
        if (flagParts.length > 1 && !/^[[<]/.test(flagParts[1]))
            this.short = flagParts.shift();
        this.long = flagParts.shift();
        this.description = description || '';
        this.defaultValue = undefined;
    }
    name() {
        return this.long.replace(/^--/, '');
    }
    attributeName() {
        return camelcase(this.name().replace(/^no-/, ''));
    }
    is(arg) {
        return this.short === arg || this.long === arg;
    }
}
class CommanderError extends Error {
    constructor(exitCode, code, message) {
        super(message);
        Error.captureStackTrace(this, this.constructor);
        this.name = this.constructor.name;
        this.code = code;
        this.exitCode = exitCode;
        this.nestedError = undefined;
    }
}
class Command extends EventEmitter {
    constructor(name) {
        super();
        this.commands = [];
        this.options = [];
        this.parent = null;
        this._allowUnknownOption = false;
        this._args = [];
        this.rawArgs = null;
        this._scriptPath = null;
        this._name = name || '';
        this._optionValues = {};
        this._storeOptionsAsProperties = true;
        this._passCommandToAction = true;
        this._actionResults = [];
        this._actionHandler = null;
        this._executableHandler = false;
        this._executableFile = null;
        this._defaultCommandName = null;
        this._exitCallback = null;
        this._alias = null;
        this._noHelp = false;
        this._helpFlags = '-h, --help';
        this._helpDescription = 'display help for command';
        this._helpShortFlag = '-h';
        this._helpLongFlag = '--help';
        this._hasImplicitHelpCommand = undefined;
        this._helpCommandName = 'help';
        this._helpCommandnameAndArgs = 'help [command]';
        this._helpCommandDescription = 'display help for command';
    }
    command(nameAndArgs, actionOptsOrExecDesc, execOpts) {
        let desc = actionOptsOrExecDesc;
        let opts = execOpts;
        if (typeof desc === 'object' && desc !== null) {
            opts = desc;
            desc = null;
        }
        opts = opts || {};
        const args = nameAndArgs.split(/ +/);
        const cmd = this.createCommand(args.shift());
        if (desc) {
            cmd.description(desc);
            cmd._executableHandler = true;
        }
        if (opts.isDefault)
            this._defaultCommandName = cmd._name;
        cmd._noHelp = !!opts.noHelp;
        cmd._helpFlags = this._helpFlags;
        cmd._helpDescription = this._helpDescription;
        cmd._helpShortFlag = this._helpShortFlag;
        cmd._helpLongFlag = this._helpLongFlag;
        cmd._helpCommandName = this._helpCommandName;
        cmd._helpCommandnameAndArgs = this._helpCommandnameAndArgs;
        cmd._helpCommandDescription = this._helpCommandDescription;
        cmd._exitCallback = this._exitCallback;
        cmd._storeOptionsAsProperties = this._storeOptionsAsProperties;
        cmd._passCommandToAction = this._passCommandToAction;
        cmd._executableFile = opts.executableFile || null;
        this.commands.push(cmd);
        cmd._parseExpectedArgs(args);
        cmd.parent = this;
        if (desc)
            return this;
        return cmd;
    }
    createCommand(name) {
        return new Command(name);
    }
    addCommand(cmd) {
        if (!cmd._name)
            throw new Error('Command passed to .addCommand() must have a name');
        function checkExplicitNames(commandArray) {
            commandArray.forEach(cmd => {
                if (cmd._executableHandler && !cmd._executableFile) {
                    throw new Error(`Must specify executableFile for deeply nested executable: ${ cmd.name() }`);
                }
                checkExplicitNames(cmd.commands);
            });
        }
        checkExplicitNames(cmd.commands);
        this.commands.push(cmd);
        cmd.parent = this;
        return this;
    }
    arguments(desc) {
        return this._parseExpectedArgs(desc.split(/ +/));
    }
    addHelpCommand(enableOrNameAndArgs, description) {
        if (enableOrNameAndArgs === false) {
            this._hasImplicitHelpCommand = false;
        } else {
            this._hasImplicitHelpCommand = true;
            if (typeof enableOrNameAndArgs === 'string') {
                this._helpCommandName = enableOrNameAndArgs.split(' ')[0];
                this._helpCommandnameAndArgs = enableOrNameAndArgs;
            }
            this._helpCommandDescription = description || this._helpCommandDescription;
        }
        return this;
    }
    _lazyHasImplicitHelpCommand() {
        if (this._hasImplicitHelpCommand === undefined) {
            this._hasImplicitHelpCommand = this.commands.length && !this._actionHandler && !this._findCommand('help');
        }
        return this._hasImplicitHelpCommand;
    }
    _parseExpectedArgs(args) {
        if (!args.length)
            return;
        args.forEach(arg => {
            const argDetails = {
                required: false,
                name: '',
                variadic: false
            };
            switch (arg[0]) {
            case '<':
                argDetails.required = true;
                argDetails.name = arg.slice(1, -1);
                break;
            case '[':
                argDetails.name = arg.slice(1, -1);
                break;
            }
            if (argDetails.name.length > 3 && argDetails.name.slice(-3) === '...') {
                argDetails.variadic = true;
                argDetails.name = argDetails.name.slice(0, -3);
            }
            if (argDetails.name) {
                this._args.push(argDetails);
            }
        });
        this._args.forEach((arg, i) => {
            if (arg.variadic && i < this._args.length - 1) {
                throw new Error(`only the last argument can be variadic '${ arg.name }'`);
            }
        });
        return this;
    }
    exitOverride(fn) {
        if (fn) {
            this._exitCallback = fn;
        } else {
            this._exitCallback = err => {
                if (err.code !== 'commander.executeSubCommandAsync') {
                    throw err;
                } else {
                }
            };
        }
        return this;
    }
    _exit(exitCode, code, message) {
        if (this._exitCallback) {
            this._exitCallback(new CommanderError(exitCode, code, message));
        }
        process.exit(exitCode);
    }
    action(fn) {
        const listener = args => {
            const expectedArgsCount = this._args.length;
            const actionArgs = args.slice(0, expectedArgsCount);
            if (this._passCommandToAction) {
                actionArgs[expectedArgsCount] = this;
            } else {
                actionArgs[expectedArgsCount] = this.opts();
            }
            if (args.length > expectedArgsCount) {
                actionArgs.push(args.slice(expectedArgsCount));
            }
            const actionResult = fn.apply(this, actionArgs);
            let rootCommand = this;
            while (rootCommand.parent) {
                rootCommand = rootCommand.parent;
            }
            rootCommand._actionResults.push(actionResult);
        };
        this._actionHandler = listener;
        return this;
    }
    _optionEx(config, flags, description, fn, defaultValue) {
        const option = new Option(flags, description);
        const oname = option.name();
        const name = option.attributeName();
        option.mandatory = !!config.mandatory;
        if (typeof fn !== 'function') {
            if (fn instanceof RegExp) {
                const regex = fn;
                fn = (val, def) => {
                    const m = regex.exec(val);
                    return m ? m[0] : def;
                };
            } else {
                defaultValue = fn;
                fn = null;
            }
        }
        if (option.negate || option.optional || option.required || typeof defaultValue === 'boolean') {
            if (option.negate) {
                const positiveLongFlag = option.long.replace(/^--no-/, '--');
                defaultValue = this._findOption(positiveLongFlag) ? this._getOptionValue(name) : true;
            }
            if (defaultValue !== undefined) {
                this._setOptionValue(name, defaultValue);
                option.defaultValue = defaultValue;
            }
        }
        this.options.push(option);
        this.on('option:' + oname, val => {
            if (val !== null && fn) {
                val = fn(val, this._getOptionValue(name) === undefined ? defaultValue : this._getOptionValue(name));
            }
            if (typeof this._getOptionValue(name) === 'boolean' || typeof this._getOptionValue(name) === 'undefined') {
                if (val == null) {
                    this._setOptionValue(name, option.negate ? false : defaultValue || true);
                } else {
                    this._setOptionValue(name, val);
                }
            } else if (val !== null) {
                this._setOptionValue(name, option.negate ? false : val);
            }
        });
        return this;
    }
    option(flags, description, fn, defaultValue) {
        return this._optionEx({}, flags, description, fn, defaultValue);
    }
    requiredOption(flags, description, fn, defaultValue) {
        return this._optionEx({ mandatory: true }, flags, description, fn, defaultValue);
    }
    allowUnknownOption(arg) {
        this._allowUnknownOption = arguments.length === 0 || arg;
        return this;
    }
    storeOptionsAsProperties(value) {
        this._storeOptionsAsProperties = value === undefined || value;
        if (this.options.length) {
            throw new Error('call .storeOptionsAsProperties() before adding options');
        }
        return this;
    }
    passCommandToAction(value) {
        this._passCommandToAction = value === undefined || value;
        return this;
    }
    _setOptionValue(key, value) {
        if (this._storeOptionsAsProperties) {
            this[key] = value;
        } else {
            this._optionValues[key] = value;
        }
    }
    _getOptionValue(key) {
        if (this._storeOptionsAsProperties) {
            return this[key];
        }
        return this._optionValues[key];
    }
    parse(argv, parseOptions) {
        if (argv !== undefined && !Array.isArray(argv)) {
            throw new Error('first parameter to parse must be array or undefined');
        }
        parseOptions = parseOptions || {};
        if (argv === undefined) {
            argv = process.argv;
            if (process.versions && process.versions.electron) {
                parseOptions.from = 'electron';
            }
        }
        this.rawArgs = argv.slice();
        let userArgs;
        switch (parseOptions.from) {
        case undefined:
        case 'node':
            this._scriptPath = argv[1];
            userArgs = argv.slice(2);
            break;
        case 'electron':
            if (process.defaultApp) {
                this._scriptPath = argv[1];
                userArgs = argv.slice(2);
            } else {
                userArgs = argv.slice(1);
            }
            break;
        case 'user':
            userArgs = argv.slice(0);
            break;
        default:
            throw new Error(`unexpected parse option { from: '${ parseOptions.from }' }`);
        }
        if (!this._scriptPath && process.mainModule) {
            this._scriptPath = process.mainModule.filename;
        }
        this._name = this._name || this._scriptPath && path.basename(this._scriptPath, path.extname(this._scriptPath));
        this._parseCommand([], userArgs);
        return this;
    }
    parseAsync(argv, parseOptions) {
        this.parse(argv, parseOptions);
        return Promise.all(this._actionResults).then(() => this);
    }
    _executeSubCommand(subcommand, args) {
        args = args.slice();
        let launchWithNode = false;
        const sourceExt = [
            '.js',
            '.ts',
            '.mjs'
        ];
        this._checkForMissingMandatoryOptions();
        const scriptPath = this._scriptPath;
        let baseDir;
        try {
            const resolvedLink = fs.realpathSync(scriptPath);
            baseDir = path.dirname(resolvedLink);
        } catch (e) {
            baseDir = '.';
        }
        let bin = path.basename(scriptPath, path.extname(scriptPath)) + '-' + subcommand._name;
        if (subcommand._executableFile) {
            bin = subcommand._executableFile;
        }
        const localBin = path.join(baseDir, bin);
        if (fs.existsSync(localBin)) {
            bin = localBin;
        } else {
            sourceExt.forEach(ext => {
                if (fs.existsSync(`${ localBin }${ ext }`)) {
                    bin = `${ localBin }${ ext }`;
                }
            });
        }
        launchWithNode = sourceExt.includes(path.extname(bin));
        let proc;
        if (process.platform !== 'win32') {
            if (launchWithNode) {
                args.unshift(bin);
                args = incrementNodeInspectorPort(process.execArgv).concat(args);
                proc = spawn(process.argv[0], args, { stdio: 'inherit' });
            } else {
                proc = spawn(bin, args, { stdio: 'inherit' });
            }
        } else {
            args.unshift(bin);
            args = incrementNodeInspectorPort(process.execArgv).concat(args);
            proc = spawn(process.execPath, args, { stdio: 'inherit' });
        }
        const signals = [
            'SIGUSR1',
            'SIGUSR2',
            'SIGTERM',
            'SIGINT',
            'SIGHUP'
        ];
        signals.forEach(signal => {
            process.on(signal, () => {
                if (proc.killed === false && proc.exitCode === null) {
                    proc.kill(signal);
                }
            });
        });
        const exitCallback = this._exitCallback;
        if (!exitCallback) {
            proc.on('close', process.exit.bind(process));
        } else {
            proc.on('close', () => {
                exitCallback(new CommanderError(process.exitCode || 0, 'commander.executeSubCommandAsync', '(close)'));
            });
        }
        proc.on('error', err => {
            if (err.code === 'ENOENT') {
                const executableMissing = `'${ bin }' does not exist
 - if '${ subcommand._name }' is not meant to be an executable command, remove description parameter from '.command()' and use '.description()' instead
 - if the default executable name is not suitable, use the executableFile option to supply a custom name`;
                throw new Error(executableMissing);
            } else if (err.code === 'EACCES') {
                throw new Error(`'${ bin }' not executable`);
            }
            if (!exitCallback) {
                process.exit(1);
            } else {
                const wrappedError = new CommanderError(1, 'commander.executeSubCommandAsync', '(error)');
                wrappedError.nestedError = err;
                exitCallback(wrappedError);
            }
        });
        this.runningCommand = proc;
    }
    _dispatchSubcommand(commandName, operands, unknown) {
        const subCommand = this._findCommand(commandName);
        if (!subCommand)
            this._helpAndError();
        if (subCommand._executableHandler) {
            this._executeSubCommand(subCommand, operands.concat(unknown));
        } else {
            subCommand._parseCommand(operands, unknown);
        }
    }
    _parseCommand(operands, unknown) {
        const parsed = this.parseOptions(unknown);
        operands = operands.concat(parsed.operands);
        unknown = parsed.unknown;
        this.args = operands.concat(unknown);
        if (operands && this._findCommand(operands[0])) {
            this._dispatchSubcommand(operands[0], operands.slice(1), unknown);
        } else if (this._lazyHasImplicitHelpCommand() && operands[0] === this._helpCommandName) {
            if (operands.length === 1) {
                this.help();
            } else {
                this._dispatchSubcommand(operands[1], [], [this._helpLongFlag]);
            }
        } else if (this._defaultCommandName) {
            outputHelpIfRequested(this, unknown);
            this._dispatchSubcommand(this._defaultCommandName, operands, unknown);
        } else {
            if (this.commands.length && this.args.length === 0 && !this._actionHandler && !this._defaultCommandName) {
                this._helpAndError();
            }
            outputHelpIfRequested(this, parsed.unknown);
            this._checkForMissingMandatoryOptions();
            if (parsed.unknown.length > 0) {
                this.unknownOption(parsed.unknown[0]);
            }
            if (this._actionHandler) {
                const args = this.args.slice();
                this._args.forEach((arg, i) => {
                    if (arg.required && args[i] == null) {
                        this.missingArgument(arg.name);
                    } else if (arg.variadic) {
                        args[i] = args.splice(i);
                    }
                });
                this._actionHandler(args);
                this.emit('command:' + this.name(), operands, unknown);
            } else if (operands.length) {
                if (this._findCommand('*')) {
                    this._dispatchSubcommand('*', operands, unknown);
                } else if (this.listenerCount('command:*')) {
                    this.emit('command:*', operands, unknown);
                } else if (this.commands.length) {
                    this.unknownCommand();
                }
            } else if (this.commands.length) {
                this._helpAndError();
            } else {
            }
        }
    }
    _findCommand(name) {
        if (!name)
            return undefined;
        return this.commands.find(cmd => cmd._name === name || cmd._alias === name);
    }
    _findOption(arg) {
        return this.options.find(option => option.is(arg));
    }
    _checkForMissingMandatoryOptions() {
        for (let cmd = this; cmd; cmd = cmd.parent) {
            cmd.options.forEach(anOption => {
                if (anOption.mandatory && cmd._getOptionValue(anOption.attributeName()) === undefined) {
                    cmd.missingMandatoryOptionValue(anOption);
                }
            });
        }
    }
    parseOptions(argv) {
        const operands = [];
        const unknown = [];
        let dest = operands;
        const args = argv.slice();
        function maybeOption(arg) {
            return arg.length > 1 && arg[0] === '-';
        }
        while (args.length) {
            const arg = args.shift();
            if (arg === '--') {
                if (dest === unknown)
                    dest.push(arg);
                dest.push(...args);
                break;
            }
            if (maybeOption(arg)) {
                const option = this._findOption(arg);
                if (option) {
                    if (option.required) {
                        const value = args.shift();
                        if (value === undefined)
                            this.optionMissingArgument(option);
                        this.emit(`option:${ option.name() }`, value);
                    } else if (option.optional) {
                        let value = null;
                        if (args.length > 0 && !maybeOption(args[0])) {
                            value = args.shift();
                        }
                        this.emit(`option:${ option.name() }`, value);
                    } else {
                        this.emit(`option:${ option.name() }`);
                    }
                    continue;
                }
            }
            if (arg.length > 2 && arg[0] === '-' && arg[1] !== '-') {
                const option = this._findOption(`-${ arg[1] }`);
                if (option) {
                    if (option.required || option.optional) {
                        this.emit(`option:${ option.name() }`, arg.slice(2));
                    } else {
                        this.emit(`option:${ option.name() }`);
                        args.unshift(`-${ arg.slice(2) }`);
                    }
                    continue;
                }
            }
            if (/^--[^=]+=/.test(arg)) {
                const index = arg.indexOf('=');
                const option = this._findOption(arg.slice(0, index));
                if (option && (option.required || option.optional)) {
                    this.emit(`option:${ option.name() }`, arg.slice(index + 1));
                    continue;
                }
            }
            if (arg.length > 1 && arg[0] === '-') {
                dest = unknown;
            }
            dest.push(arg);
        }
        return {
            operands,
            unknown
        };
    }
    opts() {
        if (this._storeOptionsAsProperties) {
            const result = {};
            const len = this.options.length;
            for (let i = 0; i < len; i++) {
                const key = this.options[i].attributeName();
                result[key] = key === this._versionOptionName ? this._version : this[key];
            }
            return result;
        }
        return this._optionValues;
    }
    missingArgument(name) {
        const message = `error: missing required argument '${ name }'`;
        console.error(message);
        this._exit(1, 'commander.missingArgument', message);
    }
    optionMissingArgument(option, flag) {
        let message;
        if (flag) {
            message = `error: option '${ option.flags }' argument missing, got '${ flag }'`;
        } else {
            message = `error: option '${ option.flags }' argument missing`;
        }
        console.error(message);
        this._exit(1, 'commander.optionMissingArgument', message);
    }
    missingMandatoryOptionValue(option) {
        const message = `error: required option '${ option.flags }' not specified`;
        console.error(message);
        this._exit(1, 'commander.missingMandatoryOptionValue', message);
    }
    unknownOption(flag) {
        if (this._allowUnknownOption)
            return;
        const message = `error: unknown option '${ flag }'`;
        console.error(message);
        this._exit(1, 'commander.unknownOption', message);
    }
    unknownCommand() {
        const partCommands = [this.name()];
        for (let parentCmd = this.parent; parentCmd; parentCmd = parentCmd.parent) {
            partCommands.unshift(parentCmd.name());
        }
        const fullCommand = partCommands.join(' ');
        const message = `error: unknown command '${ this.args[0] }'. See '${ fullCommand } ${ this._helpLongFlag }'.`;
        console.error(message);
        this._exit(1, 'commander.unknownCommand', message);
    }
    version(str, flags, description) {
        if (arguments.length === 0)
            return this._version;
        this._version = str;
        flags = flags || '-V, --version';
        description = description || 'output the version number';
        const versionOption = new Option(flags, description);
        this._versionOptionName = versionOption.long.substr(2) || 'version';
        this.options.push(versionOption);
        this.on('option:' + this._versionOptionName, () => {
            process.stdout.write(str + '\n');
            this._exit(0, 'commander.version', str);
        });
        return this;
    }
    description(str, argsDescription) {
        if (arguments.length === 0)
            return this._description;
        this._description = str;
        this._argsDescription = argsDescription;
        return this;
    }
    alias(alias) {
        let command = this;
        if (this.commands.length !== 0) {
            command = this.commands[this.commands.length - 1];
        }
        if (arguments.length === 0)
            return command._alias;
        if (alias === command._name)
            throw new Error('Command alias can\'t be the same as its name');
        command._alias = alias;
        return this;
    }
    usage(str) {
        const args = this._args.map(arg => {
            return humanReadableArgName(arg);
        });
        const usage = '[options]' + (this.commands.length ? ' [command]' : '') + (this._args.length ? ' ' + args.join(' ') : '');
        if (arguments.length === 0)
            return this._usage || usage;
        this._usage = str;
        return this;
    }
    name(str) {
        if (arguments.length === 0)
            return this._name;
        this._name = str;
        return this;
    }
    prepareCommands() {
        const commandDetails = this.commands.filter(cmd => {
            return !cmd._noHelp;
        }).map(cmd => {
            const args = cmd._args.map(arg => {
                return humanReadableArgName(arg);
            }).join(' ');
            return [
                cmd._name + (cmd._alias ? '|' + cmd._alias : '') + (cmd.options.length ? ' [options]' : '') + (args ? ' ' + args : ''),
                cmd._description
            ];
        });
        if (this._lazyHasImplicitHelpCommand()) {
            commandDetails.push([
                this._helpCommandnameAndArgs,
                this._helpCommandDescription
            ]);
        }
        return commandDetails;
    }
    largestCommandLength() {
        const commands = this.prepareCommands();
        return commands.reduce((max, command) => {
            return Math.max(max, command[0].length);
        }, 0);
    }
    largestOptionLength() {
        const options = [].slice.call(this.options);
        options.push({ flags: this._helpFlags });
        return options.reduce((max, option) => {
            return Math.max(max, option.flags.length);
        }, 0);
    }
    largestArgLength() {
        return this._args.reduce((max, arg) => {
            return Math.max(max, arg.name.length);
        }, 0);
    }
    padWidth() {
        let width = this.largestOptionLength();
        if (this._argsDescription && this._args.length) {
            if (this.largestArgLength() > width) {
                width = this.largestArgLength();
            }
        }
        if (this.commands && this.commands.length) {
            if (this.largestCommandLength() > width) {
                width = this.largestCommandLength();
            }
        }
        return width;
    }
    optionHelp() {
        const width = this.padWidth();
        const columns = process.stdout.columns || 80;
        const descriptionWidth = columns - width - 4;
        return this.options.map(option => {
            const fullDesc = option.description + (!option.negate && option.defaultValue !== undefined ? ' (default: ' + JSON.stringify(option.defaultValue) + ')' : '');
            return pad(option.flags, width) + '  ' + optionalWrap(fullDesc, descriptionWidth, width + 2);
        }).concat([pad(this._helpFlags, width) + '  ' + optionalWrap(this._helpDescription, descriptionWidth, width + 2)]).join('\n');
    }
    commandHelp() {
        if (!this.commands.length && !this._lazyHasImplicitHelpCommand())
            return '';
        const commands = this.prepareCommands();
        const width = this.padWidth();
        const columns = process.stdout.columns || 80;
        const descriptionWidth = columns - width - 4;
        return [
            'Commands:',
            commands.map(cmd => {
                const desc = cmd[1] ? '  ' + cmd[1] : '';
                return (desc ? pad(cmd[0], width) : cmd[0]) + optionalWrap(desc, descriptionWidth, width + 2);
            }).join('\n').replace(/^/gm, '  '),
            ''
        ].join('\n');
    }
    helpInformation() {
        let desc = [];
        if (this._description) {
            desc = [
                this._description,
                ''
            ];
            const argsDescription = this._argsDescription;
            if (argsDescription && this._args.length) {
                const width = this.padWidth();
                const columns = process.stdout.columns || 80;
                const descriptionWidth = columns - width - 5;
                desc.push('Arguments:');
                desc.push('');
                this._args.forEach(arg => {
                    desc.push('  ' + pad(arg.name, width) + '  ' + wrap(argsDescription[arg.name], descriptionWidth, width + 4));
                });
                desc.push('');
            }
        }
        let cmdName = this._name;
        if (this._alias) {
            cmdName = cmdName + '|' + this._alias;
        }
        let parentCmdNames = '';
        for (let parentCmd = this.parent; parentCmd; parentCmd = parentCmd.parent) {
            parentCmdNames = parentCmd.name() + ' ' + parentCmdNames;
        }
        const usage = [
            'Usage: ' + parentCmdNames + cmdName + ' ' + this.usage(),
            ''
        ];
        let cmds = [];
        const commandHelp = this.commandHelp();
        if (commandHelp)
            cmds = [commandHelp];
        const options = [
            'Options:',
            '' + this.optionHelp().replace(/^/gm, '  '),
            ''
        ];
        return usage.concat(desc).concat(options).concat(cmds).join('\n');
    }
    outputHelp(cb) {
        if (!cb) {
            cb = passthru => {
                return passthru;
            };
        }
        const cbOutput = cb(this.helpInformation());
        if (typeof cbOutput !== 'string' && !Buffer.isBuffer(cbOutput)) {
            throw new Error('outputHelp callback must return a string or a Buffer');
        }
        process.stdout.write(cbOutput);
        this.emit(this._helpLongFlag);
    }
    helpOption(flags, description) {
        this._helpFlags = flags || this._helpFlags;
        this._helpDescription = description || this._helpDescription;
        const splitFlags = this._helpFlags.split(/[ ,|]+/);
        if (splitFlags.length > 1)
            this._helpShortFlag = splitFlags.shift();
        this._helpLongFlag = splitFlags.shift();
        return this;
    }
    help(cb) {
        this.outputHelp(cb);
        this._exit(process.exitCode || 0, 'commander.help', '(outputHelp)');
    }
    _helpAndError() {
        this.outputHelp();
        this._exit(1, 'commander.help', '(outputHelp)');
    }
}
;
exports = module.exports = new Command();
exports.program = exports;
exports.Command = Command;
exports.Option = Option;
exports.CommanderError = CommanderError;
function camelcase(flag) {
    return flag.split('-').reduce((str, word) => {
        return str + word[0].toUpperCase() + word.slice(1);
    });
}
function pad(str, width) {
    const len = Math.max(0, width - str.length);
    return str + Array(len + 1).join(' ');
}
function wrap(str, width, indent) {
    const regex = new RegExp('.{1,' + (width - 1) + '}([\\s\u200B]|$)|[^\\s\u200B]+?([\\s\u200B]|$)', 'g');
    const lines = str.match(regex) || [];
    return lines.map((line, i) => {
        if (line.slice(-1) === '\n') {
            line = line.slice(0, line.length - 1);
        }
        return (i > 0 && indent ? Array(indent + 1).join(' ') : '') + line.trimRight();
    }).join('\n');
}
function optionalWrap(str, width, indent) {
    if (str.match(/[\n]\s+/))
        return str;
    const minWidth = 40;
    if (width < minWidth)
        return str;
    return wrap(str, width, indent);
}
function outputHelpIfRequested(cmd, args) {
    const helpOption = args.find(arg => arg === cmd._helpLongFlag || arg === cmd._helpShortFlag);
    if (helpOption) {
        cmd.outputHelp();
        cmd._exit(0, 'commander.helpDisplayed', '(outputHelp)');
    }
}
function humanReadableArgName(arg) {
    const nameOutput = arg.name + (arg.variadic === true ? '...' : '');
    return arg.required ? '<' + nameOutput + '>' : '[' + nameOutput + ']';
}
function incrementNodeInspectorPort(args) {
    return args.map(arg => {
        let result = arg;
        if (arg.indexOf('--inspect') === 0) {
            let debugOption;
            let debugHost = '127.0.0.1';
            let debugPort = '9229';
            let match;
            if ((match = arg.match(/^(--inspect(-brk)?)$/)) !== null) {
                debugOption = match[1];
            } else if ((match = arg.match(/^(--inspect(-brk|-port)?)=([^:]+)$/)) !== null) {
                debugOption = match[1];
                if (/^\d+$/.test(match[3])) {
                    debugPort = match[3];
                } else {
                    debugHost = match[3];
                }
            } else if ((match = arg.match(/^(--inspect(-brk|-port)?)=([^:]+):(\d+)$/)) !== null) {
                debugOption = match[1];
                debugHost = match[3];
                debugPort = match[4];
            }
            if (debugOption && debugPort !== '0') {
                result = `${ debugOption }=${ debugHost }:${ parseInt(debugPort) + 1 }`;
            }
        }
        return result;
    });
}
}
// has-flag@4.0.0/index.js
$fsx.f[12] =
function(module,exports){
module.exports = (flag, argv = process.argv) => {
    const prefix = flag.startsWith('-') ? '' : flag.length === 1 ? '-' : '--';
    const position = argv.indexOf(prefix + flag);
    const terminatorPosition = argv.indexOf('--');
    return position !== -1 && (terminatorPosition === -1 || position < terminatorPosition);
};
}
// import-lazy/index.js
$fsx.f[13] =
function(module,exports){
const lazy = (mod, fn, id) => mod === undefined ? fn(id) : mod;
module.exports = fn => {
    return id => {
        let mod;
        return function () {
            if (arguments.length === 0) {
                mod = lazy(mod, fn, id);
                return mod;
            }
            const ret = {};
            [].forEach.call(arguments, prop => {
                Object.defineProperty(ret, prop, {
                    get: () => {
                        mod = lazy(mod, fn, id);
                        if (typeof mod[prop] === 'function') {
                            return function () {
                                return mod[prop].apply(mod, arguments);
                            };
                        }
                        return mod[prop];
                    }
                });
            });
            return ret;
        };
    };
};
module.exports.proxy = fn => {
    return id => {
        let mod;
        const handler = {
            get: (target, property) => {
                mod = lazy(mod, fn, id);
                return Reflect.get(mod, property);
            },
            apply: (target, thisArg, argumentsList) => {
                mod = lazy(mod, fn, id);
                return Reflect.apply(mod, thisArg, argumentsList);
            }
        };
        return new Proxy(() => {
        }, handler);
    };
};
}
// supports-color@7.1.0/index.js
$fsx.f[14] =
function(module,exports){
const os = $fsx.s('os');
const tty = $fsx.s('tty');
const hasFlag = $fsx.r(12);
const {env} = process;
let forceColor;
if (hasFlag('no-color') || hasFlag('no-colors') || hasFlag('color=false') || hasFlag('color=never')) {
    forceColor = 0;
} else if (hasFlag('color') || hasFlag('colors') || hasFlag('color=true') || hasFlag('color=always')) {
    forceColor = 1;
}
if ('FORCE_COLOR' in env) {
    if (env.FORCE_COLOR === 'true') {
        forceColor = 1;
    } else if (env.FORCE_COLOR === 'false') {
        forceColor = 0;
    } else {
        forceColor = env.FORCE_COLOR.length === 0 ? 1 : Math.min(parseInt(env.FORCE_COLOR, 10), 3);
    }
}
function translateLevel(level) {
    if (level === 0) {
        return false;
    }
    return {
        level,
        hasBasic: true,
        has256: level >= 2,
        has16m: level >= 3
    };
}
function supportsColor(haveStream, streamIsTTY) {
    if (forceColor === 0) {
        return 0;
    }
    if (hasFlag('color=16m') || hasFlag('color=full') || hasFlag('color=truecolor')) {
        return 3;
    }
    if (hasFlag('color=256')) {
        return 2;
    }
    if (haveStream && !streamIsTTY && forceColor === undefined) {
        return 0;
    }
    const min = forceColor || 0;
    if (env.TERM === 'dumb') {
        return min;
    }
    if (process.platform === 'win32') {
        const osRelease = os.release().split('.');
        if (Number(osRelease[0]) >= 10 && Number(osRelease[2]) >= 10586) {
            return Number(osRelease[2]) >= 14931 ? 3 : 2;
        }
        return 1;
    }
    if ('CI' in env) {
        if ([
                'TRAVIS',
                'CIRCLECI',
                'APPVEYOR',
                'GITLAB_CI'
            ].some(sign => sign in env) || env.CI_NAME === 'codeship') {
            return 1;
        }
        return min;
    }
    if ('TEAMCITY_VERSION' in env) {
        return /^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(env.TEAMCITY_VERSION) ? 1 : 0;
    }
    if ('GITHUB_ACTIONS' in env) {
        return 1;
    }
    if (env.COLORTERM === 'truecolor') {
        return 3;
    }
    if ('TERM_PROGRAM' in env) {
        const version = parseInt((env.TERM_PROGRAM_VERSION || '').split('.')[0], 10);
        switch (env.TERM_PROGRAM) {
        case 'iTerm.app':
            return version >= 3 ? 3 : 2;
        case 'Apple_Terminal':
            return 2;
        }
    }
    if (/-256(color)?$/i.test(env.TERM)) {
        return 2;
    }
    if (/^screen|^xterm|^vt100|^vt220|^rxvt|color|ansi|cygwin|linux/i.test(env.TERM)) {
        return 1;
    }
    if ('COLORTERM' in env) {
        return 1;
    }
    return min;
}
function getSupportLevel(stream) {
    const level = supportsColor(stream, stream && stream.isTTY);
    return translateLevel(level);
}
module.exports = {
    supportsColor: getSupportLevel,
    stdout: translateLevel(supportsColor(true, tty.isatty(1))),
    stderr: translateLevel(supportsColor(true, tty.isatty(2)))
};
}
// update-notifier/index.js
$fsx.f[15] =
function(module,exports){
var __dirname = ".";
const {spawn} = $fsx.s('child_process');
const path = $fsx.s('path');
const {format} = $fsx.s('util');
const importLazy = $fsx.r(13)($fsx);
const configstore = importLazy('configstore');
const chalk = importLazy('chalk');
const semverDiff = importLazy('semver-diff');
const latestVersion = importLazy('latest-version');
const isNpm = importLazy('is-npm');
const isInstalledGlobally = importLazy('is-installed-globally');
const isYarnGlobal = importLazy('is-yarn-global');
const hasYarn = importLazy('has-yarn');
const boxen = importLazy('boxen');
const xdgBasedir = importLazy('xdg-basedir');
const isCi = importLazy('is-ci');
const pupa = importLazy('pupa');
const ONE_DAY = 1000 * 60 * 60 * 24;
class UpdateNotifier {
    constructor(options = {}) {
        this.options = options;
        options.pkg = options.pkg || {};
        options.distTag = options.distTag || 'latest';
        options.pkg = {
            name: options.pkg.name || options.packageName,
            version: options.pkg.version || options.packageVersion
        };
        if (!options.pkg.name || !options.pkg.version) {
            throw new Error('pkg.name and pkg.version required');
        }
        this.packageName = options.pkg.name;
        this.packageVersion = options.pkg.version;
        this.updateCheckInterval = typeof options.updateCheckInterval === 'number' ? options.updateCheckInterval : ONE_DAY;
        this.disabled = 'NO_UPDATE_NOTIFIER' in process.env || process.env.NODE_ENV === 'test' || process.argv.includes('--no-update-notifier') || isCi();
        this.shouldNotifyInNpmScript = options.shouldNotifyInNpmScript;
        if (!this.disabled) {
            try {
                const ConfigStore = configstore();
                this.config = new ConfigStore(`update-notifier-${ this.packageName }`, {
                    optOut: false,
                    lastUpdateCheck: Date.now()
                });
            } catch (_) {
                const message = chalk().yellow(format(' %s update check failed ', options.pkg.name)) + format('\n Try running with %s or get access ', chalk().cyan('sudo')) + '\n to the local update config store via \n' + chalk().cyan(format(' sudo chown -R $USER:$(id -gn $USER) %s ', xdgBasedir().config));
                process.on('exit', () => {
                    console.error('\n' + boxen()(message, { align: 'center' }));
                });
            }
        }
    }
    check() {
        if (!this.config || this.config.get('optOut') || this.disabled) {
            return;
        }
        this.update = this.config.get('update');
        if (this.update) {
            this.update.current = this.packageVersion;
            this.config.delete('update');
        }
        if (Date.now() - this.config.get('lastUpdateCheck') < this.updateCheckInterval) {
            return;
        }
        spawn(process.execPath, [
            path.join(__dirname, 'check.js'),
            JSON.stringify(this.options)
        ], {
            detached: true,
            stdio: 'ignore'
        }).unref();
    }
    async fetchInfo() {
        const {distTag} = this.options;
        const latest = await latestVersion()(this.packageName, { version: distTag });
        return {
            latest,
            current: this.packageVersion,
            type: semverDiff()(this.packageVersion, latest) || distTag,
            name: this.packageName
        };
    }
    notify(options) {
        const suppressForNpm = !this.shouldNotifyInNpmScript && isNpm().isNpmOrYarn;
        if (!process.stdout.isTTY || suppressForNpm || !this.update || this.update.current === this.update.latest) {
            return this;
        }
        options = Object.assign({
            isGlobal: isInstalledGlobally(),
            isYarnGlobal: isYarnGlobal()()
        }, options);
        let installCommand;
        if (options.isYarnGlobal) {
            installCommand = `yarn global add ${ this.packageName }`;
        } else if (options.isGlobal) {
            installCommand = `npm i -g ${ this.packageName }`;
        } else if (hasYarn()()) {
            installCommand = `yarn add ${ this.packageName }`;
        } else {
            installCommand = `npm i ${ this.packageName }`;
        }
        const defaultTemplate = 'Update available ' + chalk().dim('{currentVersion}') + chalk().reset(' \u2192 ') + chalk().green('{latestVersion}') + ' \nRun ' + chalk().cyan('{updateCommand}') + ' to update';
        const template = options.message || defaultTemplate;
        options.boxenOptions = options.boxenOptions || {
            padding: 1,
            margin: 1,
            align: 'center',
            borderColor: 'yellow',
            borderStyle: 'round'
        };
        const message = '\n' + boxen()(pupa()(template, {
            packageName: this.packageName,
            currentVersion: this.update.current,
            latestVersion: this.update.latest,
            updateCommand: installCommand
        }), options.boxenOptions);
        if (options.defer === false) {
            console.error(message);
        } else {
            process.on('exit', () => {
                console.error(message);
            });
            process.on('SIGINT', () => {
                console.error('');
                process.exit();
            });
        }
        return this;
    }
}
module.exports = options => {
    const updateNotifier = new UpdateNotifier(options);
    updateNotifier.check();
    return updateNotifier;
};
module.exports.UpdateNotifier = UpdateNotifier;
}
$fsx.r(0)

